<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//es_ES

$LANG=array();


$LANG['backup'][0]="Copia de seguridad en SQL"; 
$LANG['backup'][1]="Copia de seguridad en XML"; 
$LANG['backup'][11]="Tamaño"; 
$LANG['backup'][13]="Ver/Descargar"; 
$LANG['backup'][16]="¿Está seguro de querer reemplazar la base de datos actual por el fichero de backup?:"; 
$LANG['backup'][17]="¿Está seguro de querer borrar este fichero?:"; 
$LANG['backup'][18]="¿Está seguro de querer guardar la base de datos?"; 
$LANG['backup'][19]="Ahora"; 
$LANG['backup'][21]="El fichero ya existe"; 
$LANG['backup'][22]="No se encuentra el byte"; 
$LANG['backup'][23]="Error MySQL empezando en"; 
$LANG['backup'][24]="Redirección automática. Si no es así, haga clic"; 

$LANG['bookmark'][1]="marcador"; 
$LANG['bookmark'][2]="Carga parcial del marcador"; 
$LANG['bookmark'][3]="No tiene marcadores guardados"; 
$LANG['bookmark'][4]="Nuevo marcador"; 
$LANG['bookmark'][5]="Marcadores Públicos"; 
$LANG['bookmark'][6]="Vista predeterminada"; 

$LANG['buttons'][0]="Buscar"; 
$LANG['buttons'][2]="Aceptar"; 
$LANG['buttons'][3]="Asignar"; 
$LANG['buttons'][4]="Instalar"; 
$LANG['buttons'][5]="Desinstalar"; 
$LANG['buttons'][6]="Borrar"; 
$LANG['buttons'][7]="Actualizar"; 
$LANG['buttons'][8]="Añadir"; 
$LANG['buttons'][9]="Conectar"; 
$LANG['buttons'][10]="Desconectar"; 
$LANG['buttons'][11]="Siguiente"; 
$LANG['buttons'][12]="Anterior"; 
$LANG['buttons'][13]="Volver"; 
$LANG['buttons'][14]="Modificar"; 
$LANG['buttons'][15]="Calendario"; 
$LANG['buttons'][16]="Borrar"; 
$LANG['buttons'][17]="Invertir la selección"; 
$LANG['buttons'][18]="Marcar todo"; 
$LANG['buttons'][19]="Desmarcar todo"; 
$LANG['buttons'][20]="Mover"; 
$LANG['buttons'][21]="Restaurar"; 
$LANG['buttons'][22]="Purgar"; 
$LANG['buttons'][23]="Ver"; 
$LANG['buttons'][24]="Ascender"; 
$LANG['buttons'][25]="Descender"; 
$LANG['buttons'][27]="Vista en formato PDF"; 
$LANG['buttons'][28]="Vista en formato SLK"; 
$LANG['buttons'][29]="Todo en formato PDF"; 
$LANG['buttons'][30]="Todo en formato SLK"; 
$LANG['buttons'][31]="Exportar"; 
$LANG['buttons'][32]="Fin"; 
$LANG['buttons'][33]="Principio"; 
$LANG['buttons'][34]="Cancelar"; 
$LANG['buttons'][37]="Importar"; 
$LANG['buttons'][38]="Desbloquear"; 
$LANG['buttons'][39]="Reemplazar"; 
$LANG['buttons'][40]="Ver todos"; 
$LANG['buttons'][41]="Activar"; 
$LANG['buttons'][42]="Desactivar"; 
$LANG['buttons'][43]="Examinar"; 
$LANG['buttons'][44]="Vista en formato CSV"; 
$LANG['buttons'][45]="Todo en formato CSV"; 
$LANG['buttons'][46]="Antes"; 
$LANG['buttons'][47]="Después"; 
$LANG['buttons'][48]="Transferir"; 
$LANG['buttons'][49]="Conservar"; 
$LANG['buttons'][50]="Probar"; 
$LANG['buttons'][51]="Registrar"; 
$LANG['buttons'][52]="Cargar"; 
$LANG['buttons'][53]="Limpiar"; 
$LANG['buttons'][55]="Primero"; 
$LANG['buttons'][56]="Último"; 
$LANG['buttons'][57]="Ejecutar"; 
$LANG['buttons'][58]="Actualizar"; 
$LANG['buttons'][59]="Disociar"; 

$LANG['calendar'][0]="AAAA-MM-DD"; 
$LANG['calendar'][1]="DD-MM-AAAA"; 
$LANG['calendar'][2]="MM-DD-AAAA"; 

$LANG['calendarD'][0]="D"; 
$LANG['calendarD'][1]="L"; 
$LANG['calendarD'][2]="M"; 
$LANG['calendarD'][3]="M"; 
$LANG['calendarD'][4]="J"; 
$LANG['calendarD'][5]="V"; 
$LANG['calendarD'][6]="S"; 

$LANG['calendarDay'][0]="Domingo"; 
$LANG['calendarDay'][1]="Lunes"; 
$LANG['calendarDay'][2]="Martes"; 
$LANG['calendarDay'][3]="Miércoles"; 
$LANG['calendarDay'][4]="Jueves"; 
$LANG['calendarDay'][5]="Viernes"; 
$LANG['calendarDay'][6]="Sábado"; 

$LANG['calendarM'][0]="Enero"; 
$LANG['calendarM'][1]="Febrero"; 
$LANG['calendarM'][2]="Marzo"; 
$LANG['calendarM'][3]="Abril"; 
$LANG['calendarM'][4]="Mayo"; 
$LANG['calendarM'][5]="Junio"; 
$LANG['calendarM'][6]="Julio"; 
$LANG['calendarM'][7]="Agosto"; 
$LANG['calendarM'][8]="Septiembre"; 
$LANG['calendarM'][9]="Octubre"; 
$LANG['calendarM'][10]="Noviembre"; 
$LANG['calendarM'][11]="Diciembre"; 

$LANG['cartridges'][0]="Cartucho"; 
$LANG['cartridges'][7]="No se hallaron cartuchos"; 
$LANG['cartridges'][9]="No hay cartuchos"; 
$LANG['cartridges'][10]="Toner"; 
$LANG['cartridges'][11]="Chorro"; 
$LANG['cartridges'][12]="Tipo de cartucho"; 
$LANG['cartridges'][13]="Nuevos"; 
$LANG['cartridges'][14]="Usados"; 
$LANG['cartridges'][15]="Usados"; 
$LANG['cartridges'][16]="Cartuchos"; 
$LANG['cartridges'][20]="Nuevo"; 
$LANG['cartridges'][21]="Usado"; 
$LANG['cartridges'][22]="Usado"; 
$LANG['cartridges'][24]="Agregado fecha"; 
$LANG['cartridges'][27]="Sobre"; 
$LANG['cartridges'][29]="Término de vida"; 
$LANG['cartridges'][32]="Modelos de impresoras compatibles"; 
$LANG['cartridges'][33]="Cartuchos usados"; 
$LANG['cartridges'][34]="No hay cartuchos libres"; 
$LANG['cartridges'][35]="Cartuchos usados"; 
$LANG['cartridges'][37]="Cinta"; 
$LANG['cartridges'][39]="Contador de impresora"; 
$LANG['cartridges'][40]="Promedio en stock"; 
$LANG['cartridges'][41]="Utilización promedio"; 
$LANG['cartridges'][42]="Páginas impresas promedio"; 

$LANG['central'][2]="Últimos"; 
$LANG['central'][4]="Sin eventos"; 
$LANG['central'][5]="Inicio"; 
$LANG['central'][6]="Desconexión"; 
$LANG['central'][7]="Ayuda"; 
$LANG['central'][8]="Agregados"; 
$LANG['central'][9]="Sus incidencias en curso"; 
$LANG['central'][10]="Incidencias nuevas"; 
$LANG['central'][12]="Vista personal"; 
$LANG['central'][13]="Vista global"; 
$LANG['central'][14]="Vista de grupo"; 
$LANG['central'][18]="Tus incidencias a cerrar"; 
$LANG['central'][19]="Sus peticiones a validar"; 

$LANG['choice'][0]="No"; 
$LANG['choice'][1]="Sí"; 

$LANG['common'][0]="Sin nombre"; 
$LANG['common'][1]="Material"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Ver los elementos borrados"; 
$LANG['common'][4]="Web"; 
$LANG['common'][5]="Fabricante"; 
$LANG['common'][6]="Nombre de la plantilla"; 
$LANG['common'][7]="Elija una plantilla"; 
$LANG['common'][8]="Gestión de plantillas..."; 
$LANG['common'][9]="Añadir una plantilla..."; 
$LANG['common'][10]="Responsable técnico"; 
$LANG['common'][11]="Vista limitada"; 
$LANG['common'][12]="Configuración"; 
$LANG['common'][13]="Plantilla"; 
$LANG['common'][14]="Plantillas"; 
$LANG['common'][15]="Lugar"; 
$LANG['common'][16]="Nombre"; 
$LANG['common'][17]="Tipo"; 
$LANG['common'][18]="Contacto"; 
$LANG['common'][19]="Número de serie"; 
$LANG['common'][20]="Número de inventario"; 
$LANG['common'][21]="Número de contacto"; 
$LANG['common'][22]="Modelo"; 
$LANG['common'][23]="Operación realizada correctamente"; 
$LANG['common'][24]="No se han seleccionado elementos o la operación está mal definida"; 
$LANG['common'][25]="Comentarios"; 
$LANG['common'][26]="Última modificación"; 
$LANG['common'][27]="Fecha"; 
$LANG['common'][28]="Borrado"; 
$LANG['common'][29]="Plugins"; 
$LANG['common'][30]="Nuevo item"; 
$LANG['common'][31]="Plantilla vacía"; 
$LANG['common'][32]="Características"; 
$LANG['common'][33]="Total"; 
$LANG['common'][34]="Usuario"; 
$LANG['common'][35]="Grupo"; 
$LANG['common'][36]="Categoría"; 
$LANG['common'][37]="Autor"; 
$LANG['common'][38]="Desglobalizar"; 
$LANG['common'][39]="Replica el elemento tantas veces como conexiones"; 
$LANG['common'][40]="¿Seguro que desea desglobalizar este elemento?"; 
$LANG['common'][41]="Alertas por correo"; 
$LANG['common'][42]="Móvil"; 
$LANG['common'][43]="Nombre"; 
$LANG['common'][44]="Valor predeterminado"; 
$LANG['common'][45]="MB máximos"; 
$LANG['common'][46]="vCard"; 
$LANG['common'][47]="Progreso"; 
$LANG['common'][48]="Apellido"; 
$LANG['common'][49]="Ninguno"; 
$LANG['common'][50]="¿Confirma el borrado?"; 
$LANG['common'][51]="Nombre completo"; 
$LANG['common'][52]="Servidor"; 
$LANG['common'][53]="Lista"; 
$LANG['common'][54]="El elemento no se encuentra"; 
$LANG['common'][55]="¿Está seguro de que desea borrar este elemento?"; 
$LANG['common'][56]="Interfaz estándar"; 
$LANG['common'][57]="Título"; 
$LANG['common'][58]="Valor máximo"; 
$LANG['common'][59]="Global"; 
$LANG['common'][60]="Activo"; 
$LANG['common'][61]="Error desconocido"; 
$LANG['common'][62]="Otro"; 
$LANG['common'][63]="Errores"; 
$LANG['common'][64]="Supervisor"; 
$LANG['common'][65]="Interfaz"; 
$LANG['common'][66]="Todos"; 
$LANG['common'][67]="Otros"; 
$LANG['common'][68]="Apaisado"; 
$LANG['common'][69]="Retrato"; 
$LANG['common'][70]="Elemento añadido correctamente"; 
$LANG['common'][71]="Elemento modificado correctamente"; 
$LANG['common'][72]="Elemento borrado correctamente"; 
$LANG['common'][73]="Elemento purgado correctamente"; 
$LANG['common'][74]="Elemento restaurado correctamente"; 
$LANG['common'][75]="No tiene permisos para hacer recursivo al elemento en esta entidad"; 
$LANG['common'][76]="Público"; 
$LANG['common'][77]="Privado"; 
$LANG['common'][78]="Hacer Público"; 
$LANG['common'][79]="Hacer privado"; 
$LANG['common'][80]="Durante la carga..."; 
$LANG['common'][81]="No mostrar items borrados"; 
$LANG['common'][82]="Mb"; 
$LANG['common'][83]="Usted no tiene permisos para realizar esta acción."; 
$LANG['common'][84]="La existencia de elementos enlazados impiden la modificación de este atributo"; 
$LANG['common'][85]="Modificar la visibilidad en las subentidades"; 
$LANG['common'][86]="Usted no tiene los permisos suficientes para modificar la visibilidad en las subentidades"; 
$LANG['common'][87]="Nueva tarjeta"; 
$LANG['common'][88]="Personal"; 
$LANG['common'][89]="Sin instalar"; 
$LANG['common'][90]="Objeto"; 
$LANG['common'][91]="Este elemento es dependiente de otro. La modificación no está permitida"; 
$LANG['common'][92]="Contacto"; 
$LANG['common'][93]="Nuevo título hijo"; 

$LANG['computers'][0]="Volumen"; 
$LANG['computers'][1]="Porcentaje libre"; 
$LANG['computers'][2]="Tamaño libre"; 
$LANG['computers'][3]="Tamaño global"; 
$LANG['computers'][4]="Sistema de ficheros"; 
$LANG['computers'][5]="Partición"; 
$LANG['computers'][6]="Punto de montaje"; 
$LANG['computers'][7]="Añadir un volumen"; 
$LANG['computers'][8]="Volúmenes"; 
$LANG['computers'][9]="S.O."; 
$LANG['computers'][10]="Número de serie del S.O."; 
$LANG['computers'][11]="Id. de producto del S.O."; 
$LANG['computers'][14]="Añadido"; 
$LANG['computers'][23]="Tipo de RAM"; 
$LANG['computers'][24]="Cantidad de RAM(MB)"; 
$LANG['computers'][25]="Tamaño HD"; 
$LANG['computers'][36]="Tipo de HD"; 
$LANG['computers'][37]="No hay monitor conectado"; 
$LANG['computers'][38]="No hay impresoras conectadas"; 
$LANG['computers'][39]="Impresoras"; 
$LANG['computers'][40]="Monitores"; 
$LANG['computers'][46]="Periféricos"; 
$LANG['computers'][47]="No hay periféricos conectados"; 
$LANG['computers'][48]="Modificación de lugar. Los elementos conectados han sido desplazados al mismo lugar que el ordenador."; 
$LANG['computers'][49]="Modificación el usuario de contacto. Los elementos conectados han tomado como contacto el del ordenador."; 
$LANG['computers'][50]="Modificación del usuario o del grupo. Los elementos relacionados se han actualizado con los mismos valores que el ordenador."; 
$LANG['computers'][51]="Origen de actualización"; 
$LANG['computers'][52]="Versión S.O."; 
$LANG['computers'][53]="Service Pack"; 
$LANG['computers'][54]="No hay teléfono conectado"; 
$LANG['computers'][55]="Teléfono(s)"; 
$LANG['computers'][56]="Modificación del estado. Los elementos relacionados se han actualizado con el estado del ordenador."; 

$LANG['connect'][0]="Conexiones directas"; 
$LANG['connect'][1]="No conectado"; 
$LANG['connect'][15]="Actualización automática de los elementos siguientes"; 
$LANG['connect'][16]="¡Cuidado! Los siguientes elementos de los dos ordenadores no coinciden"; 

$LANG['consumables'][0]="Consumibles"; 
$LANG['consumables'][1]="En stock"; 
$LANG['consumables'][2]="Referencia"; 
$LANG['consumables'][7]="No se hallaron consumibles"; 
$LANG['consumables'][9]="Ningún consumible"; 
$LANG['consumables'][12]="Tipo de consumible"; 
$LANG['consumables'][13]="Nuevos"; 
$LANG['consumables'][15]="Utilizados"; 
$LANG['consumables'][16]="Consumibles"; 
$LANG['consumables'][20]="Nuevo"; 
$LANG['consumables'][22]="Utilizados"; 
$LANG['consumables'][23]="Estado"; 
$LANG['consumables'][26]="Utilizado fecha"; 
$LANG['consumables'][32]="Dar"; 
$LANG['consumables'][35]="Consumibles usados"; 
$LANG['consumables'][36]="Lugar de Almacenamiento"; 
$LANG['consumables'][37]="Reintegrar al stock"; 
$LANG['consumables'][38]="Umbral de alarma"; 

$LANG['contract'][0]="Contrato vencido desde el"; 
$LANG['contract'][1]="Contrato en preaviso desde el"; 

$LANG['crontask'][0]="Tareas programadas"; 
$LANG['crontask'][1]="Sincroniza equipos desde OCSNG"; 
$LANG['crontask'][2]="Alertas sobre cartuchos"; 
$LANG['crontask'][3]="Envío aviso material de consumo"; 
$LANG['crontask'][4]="Envío de alertas por licencias expiradas"; 
$LANG['crontask'][5]="Envío aviso de contratos"; 
$LANG['crontask'][6]="Envío de alerta sobre información financiera"; 
$LANG['crontask'][7]="Borrado logs antiguos"; 
$LANG['crontask'][8]="Optimización de la base de datos"; 
$LANG['crontask'][9]="Recuperar correo"; 
$LANG['crontask'][10]="Verificación de la réplica de MYSQL"; 
$LANG['crontask'][11]="Comprobar actualizaciones"; 
$LANG['crontask'][12]="Limpieza de las sesiones expiradas"; 
$LANG['crontask'][13]="Limpieza de los gráficos generados"; 
$LANG['crontask'][14]="Cerrado administrativo de las incidencias"; 
$LANG['crontask'][15]="Incidencias sin resolver"; 
$LANG['crontask'][31]="Desactivada"; 
$LANG['crontask'][32]="Programado"; 
$LANG['crontask'][33]="En proceso de ejecución"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Modo de ejecución"; 
$LANG['crontask'][37]="Frecuencia de ejecución"; 
$LANG['crontask'][38]="Periodo de ejecución"; 
$LANG['crontask'][39]="Número de mensajes para recuperar"; 
$LANG['crontask'][40]="Última ejecución"; 
$LANG['crontask'][41]="Próxima ejecución"; 
$LANG['crontask'][42]="Lo antes posible"; 
$LANG['crontask'][43]="Sin tarea a realizar"; 
$LANG['crontask'][44]="Tarea finalizada, proceso parcial"; 
$LANG['crontask'][45]="Tarea finalizada, proceso completo"; 
$LANG['crontask'][46]="Tarea finalizada. nada que hacer"; 
$LANG['crontask'][47]="Listado de las últimas ejecuciones"; 
$LANG['crontask'][48]="Inicio"; 
$LANG['crontask'][50]="Número de ejecuciones"; 
$LANG['crontask'][51]="Duración mínima"; 
$LANG['crontask'][52]="Duración máxima"; 
$LANG['crontask'][53]="Duración media"; 
$LANG['crontask'][55]="Número mínimo"; 
$LANG['crontask'][56]="Número máximo"; 
$LANG['crontask'][57]="Número medio"; 
$LANG['crontask'][58]="Número total"; 
$LANG['crontask'][59]="Velocidad media"; 
$LANG['crontask'][60]="Sistema bloqueado"; 
$LANG['crontask'][61]="Plugin desactivado"; 
$LANG['crontask'][62]="Elementos"; 

$LANG['devices'][0]="Añadir un nuevo componente"; 
$LANG['devices'][1]="Disco duro"; 
$LANG['devices'][2]="Tarjeta gráfica"; 
$LANG['devices'][3]="Tarjeta de red"; 
$LANG['devices'][4]="Procesador"; 
$LANG['devices'][5]="Placa base"; 
$LANG['devices'][6]="Memoria RAM"; 
$LANG['devices'][7]="Tarjeta de sonido"; 
$LANG['devices'][19]="Lectoras"; 
$LANG['devices'][20]="Controladoras"; 
$LANG['devices'][21]="Otros componentes"; 
$LANG['devices'][22]="Cajas"; 
$LANG['devices'][23]="Alimentación"; 
$LANG['devices'][24]="predeterminado"; 
$LANG['devices'][25]="Añadir un componente"; 
$LANG['devices'][26]="Borrado de un componente"; 

$LANG['device_case'][0]="formato"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Grabación"; 
$LANG['device_drive'][1]="Velocidad"; 

$LANG['device_hdd'][0]="Rpm"; 
$LANG['device_hdd'][1]="Cache"; 
$LANG['device_hdd'][4]="Capacidad"; 

$LANG['device_iface'][0]="Velocidad"; 
$LANG['device_iface'][2]="Dirección MAC"; 

$LANG['device_moboard'][0]="Chipset"; 

$LANG['device_power'][0]="Potencia"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Frecuencia"; 
$LANG['device_ram'][2]="Tamaño"; 

$LANG['document'][1]="Checksum (SHA1)"; 
$LANG['document'][2]="Fichero"; 
$LANG['document'][3]="Asunto"; 
$LANG['document'][4]="Tipo MIME"; 
$LANG['document'][7]="Tipo de documento"; 
$LANG['document'][9]="Extensión"; 
$LANG['document'][10]="Icono"; 
$LANG['document'][11]="Descarga autorizada"; 
$LANG['document'][15]="Descarga"; 
$LANG['document'][16]="Añadir un Documento"; 
$LANG['document'][18]="Documento"; 
$LANG['document'][19]="Elementos asociados"; 
$LANG['document'][21]="Documentos Asociados"; 
$LANG['document'][22]="Fichero actual"; 
$LANG['document'][23]="El archivo es demasiado grande para ser añadido."; 
$LANG['document'][24]="Borrado correcto del fichero"; 
$LANG['document'][25]="Falló el borrado del fichero"; 
$LANG['document'][26]="El fichero es válido, y ha sido descargado correctamente."; 
$LANG['document'][27]="Potencial ataque por upload, o fichero demasiado grande. Imposible mover el fichero temporal."; 
$LANG['document'][28]="No se ha especificado ningún fichero"; 
$LANG['document'][29]="Falló la creación del directorio"; 
$LANG['document'][30]="Compruebe que tiene permisos"; 
$LANG['document'][31]="Directorio de almacenamiento de documentos inexistente:"; 
$LANG['document'][32]="Tipo de fichero no autorizado"; 
$LANG['document'][33]="Enlace web"; 
$LANG['document'][34]="Creación del directorio"; 
$LANG['document'][35]="Directorio de subida inexistente"; 
$LANG['document'][36]="Seleccionar un fichero instalado por FTP"; 
$LANG['document'][37]="No hay ficheros disponibles"; 
$LANG['document'][38]="Fichero no encontrado"; 
$LANG['document'][39]="Documento movido correctamente"; 
$LANG['document'][40]="Problema al mover el fichero"; 
$LANG['document'][41]="Documento copiado correctamente"; 
$LANG['document'][42]="Añadido por"; 
$LANG['document'][43]="Fichero desconocido"; 
$LANG['document'][44]="Nombre de fichero incorrecto"; 
$LANG['document'][45]="No tiene permisos para acceder a este fichero"; 
$LANG['document'][46]="Fallo en el envío del archivo (muy grande)"; 
$LANG['document'][48]="Ya existe un documento con este fichero"; 
$LANG['document'][49]="Fichero alterado (checksum erróneo)"; 
$LANG['document'][50]="Elementos adjuntos"; 

$LANG['entity'][0]="Entidad"; 
$LANG['entity'][2]="Entidad Raíz"; 
$LANG['entity'][3]="Asociar a una entidad"; 
$LANG['entity'][5]="Asignación automática de ordenadores"; 
$LANG['entity'][6]="Asignación automática de usuarios"; 
$LANG['entity'][7]="estructura en árbol"; 
$LANG['entity'][8]="Por entidad"; 
$LANG['entity'][9]="Subentidades"; 
$LANG['entity'][10]="Seleccionar la entidad deseada"; 
$LANG['entity'][11]="para ver la entidad y sus subentidades"; 
$LANG['entity'][12]="DN de la entidad"; 
$LANG['entity'][13]="TAG de la entidad"; 
$LANG['entity'][14]="Información avanzada"; 
$LANG['entity'][15]="Directorio asociado a la entidad"; 
$LANG['entity'][16]="Filtro de búsqueda (si fuese necesario)"; 
$LANG['entity'][17]="Configuración para el cierre administrativo"; 
$LANG['entity'][18]="Cierre administrativo de las incidencias después de resueltas"; 

$LANG['event'][0]="Item (ID)"; 
$LANG['event'][2]="Incidencia"; 
$LANG['event'][3]="Nivel"; 
$LANG['event'][4]="Mensaje"; 
$LANG['event'][18]="Campo"; 
$LANG['event'][19]="Modificación"; 
$LANG['event'][20]="No hay histórico"; 

$LANG['financial'][1]="Contrato"; 
$LANG['financial'][2]="Tiene vida"; 
$LANG['financial'][3]="Datos financieros"; 
$LANG['financial'][4]="Número"; 
$LANG['financial'][5]="Costo"; 
$LANG['financial'][6]="Tipo de contrato"; 
$LANG['financial'][8]="Duración"; 
$LANG['financial'][9]="años"; 
$LANG['financial'][10]="Preaviso"; 
$LANG['financial'][11]="Periodicidad de facturación"; 
$LANG['financial'][13]="Número contable"; 
$LANG['financial'][14]="Fecha de compra"; 
$LANG['financial'][15]="Duración de la garantía"; 
$LANG['financial'][16]="Datos de garantía"; 
$LANG['financial'][18]="Número de pedido"; 
$LANG['financial'][19]="Remito de entrega"; 
$LANG['financial'][20]="Número de inhibición"; 
$LANG['financial'][21]="Precio de compra"; 
$LANG['financial'][22]="Tipo de amortización"; 
$LANG['financial'][23]="Duración de amortización"; 
$LANG['financial'][24]="Añadir Contacto..."; 
$LANG['financial'][25]="Añadir Proveedor..."; 
$LANG['financial'][26]="Proveedor"; 
$LANG['financial'][30]="Fax"; 
$LANG['financial'][33]="Añadir un Contacto"; 
$LANG['financial'][36]="Añadir un Contrato"; 
$LANG['financial'][42]="Comercial"; 
$LANG['financial'][43]="Técnico"; 
$LANG['financial'][44]="Dirección"; 
$LANG['financial'][45]="Sitio Web"; 
$LANG['financial'][46]="Contactos asociados"; 
$LANG['financial'][47]="Lineal"; 
$LANG['financial'][48]="Reducido"; 
$LANG['financial'][50]="Préstamo"; 
$LANG['financial'][51]="Locación"; 
$LANG['financial'][52]="Leasing"; 
$LANG['financial'][53]="Seguros"; 
$LANG['financial'][54]="Mantenimiento Hardware"; 
$LANG['financial'][55]="Mantenimiento Software"; 
$LANG['financial'][56]="Prestación"; 
$LANG['financial'][57]="mes"; 
$LANG['financial'][59]="Horas de servicio"; 
$LANG['financial'][60]="de semana"; 
$LANG['financial'][61]="sábado"; 
$LANG['financial'][62]="domingo y feriados"; 
$LANG['financial'][65]="Proveedores asociados"; 
$LANG['financial'][66]="Contratos asociados"; 
$LANG['financial'][68]="Activar los datos financieros"; 
$LANG['financial'][69]="Periodicidad del contrato"; 
$LANG['financial'][76]="Fecha de puesta en servicio"; 
$LANG['financial'][77]="Coeficiente de amortización"; 
$LANG['financial'][78]="Precio extensión garantía"; 
$LANG['financial'][79]="Tipo de Tercero"; 
$LANG['financial'][80]="Expiración de garantía"; 
$LANG['financial'][81]="Valor Neto Contable (VNC)"; 
$LANG['financial'][82]="Número de factura"; 
$LANG['financial'][83]="Cantidad máxima de elementos (0=sin límites)"; 
$LANG['financial'][84]="Para este tipo de elemento, los datos financieros no son más que un modelo para los elementos que usted añadirá a continuación."; 
$LANG['financial'][85]="No se halló el elemento solicitado"; 
$LANG['financial'][86]="Caducidad de contrato"; 
$LANG['financial'][87]="Presupuesto"; 
$LANG['financial'][88]="Expira el:"; 
$LANG['financial'][89]="CTP (precio de compra + coste de incidencias)"; 
$LANG['financial'][90]="CTP mensual"; 
$LANG['financial'][91]="CTP"; 
$LANG['financial'][92]="VNC"; 
$LANG['financial'][93]="Contratos expirados hace menos de 30 días"; 
$LANG['financial'][94]="Contratos que expiran en menos de 7 días"; 
$LANG['financial'][95]="Contratos que expiran en menos de 30 días"; 
$LANG['financial'][96]="Contratos cuyo preaviso comienza en menos de 7 días"; 
$LANG['financial'][97]="Contratos cuyo preaviso comienza en menos de 30 días"; 
$LANG['financial'][98]="Expiración"; 
$LANG['financial'][99]="Expiración+preaviso"; 
$LANG['financial'][100]="Código postal"; 
$LANG['financial'][101]="Ciudad"; 
$LANG['financial'][102]="Estado"; 
$LANG['financial'][103]="País"; 
$LANG['financial'][104]="Material conectado"; 
$LANG['financial'][105]="Tácito"; 
$LANG['financial'][106]="Expresa"; 
$LANG['financial'][107]="Renovación"; 
$LANG['financial'][108]="Total gastado en el presupuesto"; 
$LANG['financial'][109]="Total restante del presupuesto"; 
$LANG['financial'][110]="Presupuestos"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="horas"; 
$LANG['gmt'][2]="h"; 

$LANG['help'][1]="Matriz de cálculo de la prioridad"; 
$LANG['help'][2]="Mayor"; 
$LANG['help'][3]="Muy urgente"; 
$LANG['help'][4]="Urgente"; 
$LANG['help'][5]="Mediana"; 
$LANG['help'][6]="Baja"; 
$LANG['help'][7]="Muy baja"; 
$LANG['help'][8]="Infórmeme del seguimiento"; 
$LANG['help'][11]="Mi dirección de correo"; 
$LANG['help'][14]="Enviar mensaje"; 
$LANG['help'][16]="Si desea estar informado del seguimiento debe introducir su dirección de correo electrónico"; 
$LANG['help'][18]="Su solicitud ha sido grabada correctamente."; 
$LANG['help'][19]="Gracias por utilizar nuestro sistema de ayuda automática."; 
$LANG['help'][22]="Buscar su número de ordenador"; 
$LANG['help'][23]="Teclee las primeras letras (nombre, material, n° de serie o nº de inventario)"; 
$LANG['help'][24]="Tipo de material"; 
$LANG['help'][25]="Ordenador"; 
$LANG['help'][26]="Electrónica de red"; 
$LANG['help'][27]="Impresora"; 
$LANG['help'][28]="Monitor"; 
$LANG['help'][29]="Periférico"; 
$LANG['help'][30]="General"; 
$LANG['help'][31]="Software"; 
$LANG['help'][35]="Teléfonos"; 
$LANG['help'][40]="Incidencia sin título, porfavor introdúzcalo."; 
$LANG['help'][41]="La incidencia no contiene categoría. Por favor, seleccione una."; 
$LANG['help'][42]="Muy alta"; 
$LANG['help'][43]="Alta"; 
$LANG['help'][44]="Mediana"; 
$LANG['help'][45]="Baja"; 
$LANG['help'][46]="Muy baja"; 
$LANG['help'][47]="Muy alto"; 
$LANG['help'][48]="Alto"; 
$LANG['help'][49]="Medio"; 
$LANG['help'][50]="Bajo"; 
$LANG['help'][51]="Muy bajo"; 

$LANG['install'][0]="Instalación o actualización de GLPI"; 
$LANG['install'][1]="Elija 'Instalación' para una nueva instalación completa de GLPI"; 
$LANG['install'][2]="Elija 'Actualización' para actualizar GLPI a partir de una versión anterior"; 
$LANG['install'][3]="Instalación"; 
$LANG['install'][4]="Actualización"; 
$LANG['install'][5]="Verificación de la compatibilidad de su entorno con la ejecución de GLPI"; 
$LANG['install'][6]="Prueba efectuada"; 
$LANG['install'][7]="Resultados"; 
$LANG['install'][8]="Prueba del intérprete PHP"; 
$LANG['install'][9]="Debe instalar al menos PHP5. Puede descargarlo de aquí:"; 
$LANG['install'][10]="GLPI no es compatible con la directiva zend.ze1_compatibility_mode = On."; 
$LANG['install'][11]="La versión de PHP es 5.x o superior - ¡Perfecto!"; 
$LANG['install'][12]="Prueba de Sesiones"; 
$LANG['install'][13]="Su intérprete PHP no ha sido compilado con soporte de sesiones!"; 
$LANG['install'][14]="El soporte de sesiones está operativo - ¡Perfecto!"; 
$LANG['install'][15]="Compruebe que esté activado el soporte de sesiones en su php.ini"; 
$LANG['install'][16]="Pruebas de escritura de ficheros dump"; 
$LANG['install'][17]="No se ha podido crear el fichero."; 
$LANG['install'][18]="Las traducciones no oficiales están tambien disponibles"; 
$LANG['install'][19]="El fichero ha sido creado pero no se ha podido borrar."; 
$LANG['install'][20]="El fichero y un directorio han sido creados y borrados - ¡Perfecto!"; 
$LANG['install'][21]="Prueba de escritura de ficheros de documentos"; 
$LANG['install'][22]="Un fichero ha sido creado - Perfecto!"; 
$LANG['install'][23]="Prueba de escritura del fichero de configuración"; 
$LANG['install'][24]="Inicialización de la base de datos"; 
$LANG['install'][25]="Continuar?"; 
$LANG['install'][26]="Continuar"; 
$LANG['install'][27]="Reintentar"; 
$LANG['install'][28]="Configuración de la conexión a la base de datos"; 
$LANG['install'][29]="Parámetros de conexión a la base de datos"; 
$LANG['install'][30]="Servidor Mysql"; 
$LANG['install'][31]="Usuario Mysql"; 
$LANG['install'][32]="Contraseña Mysql"; 
$LANG['install'][34]="Prueba de la conexión a la base de datos"; 
$LANG['install'][35]="Imposible conectarse a la base de datos"; 
$LANG['install'][36]="El servidor ha respondido"; 
$LANG['install'][37]="El campo servidor y/o el campo usuario están vacíos"; 
$LANG['install'][38]="Seleccione una base de datos:"; 
$LANG['install'][39]="Crear una nueva base de datos o utilizar la que ya existe:"; 
$LANG['install'][40]="Seleccione la base de datos a actualizar:"; 
$LANG['install'][41]="Imposible utilizar la base:"; 
$LANG['install'][43]="OK - La base ha sido inicializada"; 
$LANG['install'][47]="Imposible escribir el fichero de configuración de su base de datos"; 
$LANG['install'][48]="Error en la creación de la base!"; 
$LANG['install'][49]="No ha seleccionado base de datos!"; 
$LANG['install'][50]="Prueba de escritura de ficheros de sesiones"; 
$LANG['install'][52]="Prueba de escritura de ficheros de cron"; 
$LANG['install'][53]="Prueba de escritura de los ficheros de registro"; 
$LANG['install'][55]="La instalación ha terminado"; 
$LANG['install'][57]="Los usuarios de acceso y claves predeterminados son:"; 
$LANG['install'][58]="glpi/glpi para la cuenta administrador"; 
$LANG['install'][59]="tech/tech para la cuenta de técnico"; 
$LANG['install'][60]="normal para la cuenta normal"; 
$LANG['install'][61]="post-only/post-only para la cuenta postonly"; 
$LANG['install'][62]="Puede borrar o modificar estas cuentas así como las primeras entradas en la base de datos"; 
$LANG['install'][64]="Utilizar GLPI"; 
$LANG['install'][65]="Prueba de la extensión magic_quotes_sybase"; 
$LANG['install'][66]="GLPI no puede funcionar con la opción magic_quotes_sybase. Por favor desactive esta opción y reintente"; 
$LANG['install'][67]="Su servidor no utiliza la opción magic_quotes_sybase - ¡Perfecto!"; 
$LANG['install'][68]="Prueba sesión de autoinicio"; 
$LANG['install'][69]="session.auto_start está activada. Revisar el fichero .htaccess en la raíz de GLPI para más información"; 
$LANG['install'][70]="Imposible crear el fichero de conexión a la base de datos, compruebe los permisos sobre los ficheros"; 
$LANG['install'][71]="Prueba de la extensión mysql."; 
$LANG['install'][72]="Debe compilar su PHP con la extensión Mysql."; 
$LANG['install'][73]="OK - la función mysql_query() existe - ¡Perfecto!"; 
$LANG['install'][74]="Prueba de utilización de Session_use_trans_sid"; 
$LANG['install'][75]="Debe desactivar la opción Session_use_trans_id en su PHP.ini"; 
$LANG['install'][76]="OK - Las sesiones funcionan (no hay problemas de trans_id) - ¡Perfecto!"; 
$LANG['install'][77]="Etapa"; 
$LANG['install'][81]="Inicio de la instalación"; 
$LANG['install'][82]="Base de datos creada"; 
$LANG['install'][85]="Se han encontrado las funciones - ¡Perfecto!"; 
$LANG['install'][86]="Comprobar la memoria asignada"; 
$LANG['install'][87]="Memoria asignada:"; 
$LANG['install'][88]="Generalmente se necesita un mínimo de 64MB para GLPI."; 
$LANG['install'][89]="¡Perfecto!"; 
$LANG['install'][90]="Intente aumentar el parámetro memory_limit en el fichero php.ini."; 
$LANG['install'][91]="Memoria asignada > 64 MB"; 
$LANG['install'][92]="Licencia"; 
$LANG['install'][93]="He leído y ACEPTO los términos de la licencia enunciados arriba."; 
$LANG['install'][94]="He leído y NO ACEPTO los términos de la licencia enunciados arriba"; 
$LANG['install'][95]="Memoria no limitada"; 
$LANG['install'][96]="Memoria ilimitada"; 
$LANG['install'][97]="Compruebe que PHP tiene permiso de escritura en el directorio:"; 
$LANG['install'][99]="Prueba de escritura de los ficheros de caché"; 
$LANG['install'][100]="No se ha podido crear el directorio."; 
$LANG['install'][101]="Se ha creado el directorio pero no se ha podido borrar."; 
$LANG['install'][102]="Prueba de las funciones  json"; 
$LANG['install'][103]="GLPI no puede funcionar correctamente sin las funciones json_encode y json_decode"; 
$LANG['install'][104]="Prueba de la extensión mbstring"; 
$LANG['install'][105]="La extensión mbstring del interprete PHP no está instalada"; 
$LANG['install'][106]="Prueba de escritura de los ficheros gráficos"; 

$LANG['job'][2]="por"; 
$LANG['job'][4]="Solicitante"; 
$LANG['job'][5]="Asignada a"; 
$LANG['job'][6]="Técnico"; 
$LANG['job'][7]="Tarea"; 
$LANG['job'][8]="última(s) incidencia(s)"; 
$LANG['job'][9]="Seguimiento"; 
$LANG['job'][11]="Describa el problema/acción"; 
$LANG['job'][12]="No hay seguimiento para esta incidencia."; 
$LANG['job'][13]="Abrir una incidencia"; 
$LANG['job'][15]="Terminado"; 
$LANG['job'][19]="Seguimiento por correo"; 
$LANG['job'][20]="Duración total"; 
$LANG['job'][21]="Horas"; 
$LANG['job'][22]="Minutos"; 
$LANG['job'][29]="Añadir un nuevo seguimiento"; 
$LANG['job'][30]="Añadir una nueva tarea"; 
$LANG['job'][31]="Duración"; 
$LANG['job'][32]="Ninguna"; 
$LANG['job'][33]="Descripción vacía"; 
$LANG['job'][34]="Planificar este seguimiento"; 
$LANG['job'][35]="Planificación"; 
$LANG['job'][37]="Seguimiento"; 
$LANG['job'][38]="Incidencia"; 
$LANG['job'][39]="Modificar un seguimiento"; 
$LANG['job'][40]="Coste horario"; 
$LANG['job'][41]="Coste fijo"; 
$LANG['job'][42]="Coste del material"; 
$LANG['job'][43]="Coste total"; 
$LANG['job'][44]="Origen de la solicitud"; 
$LANG['job'][45]="Origen del seguimiento"; 
$LANG['job'][46]="Incidencia creada en la entidad"; 
$LANG['job'][47]="Costas"; 
$LANG['job'][48]="Tipo de solución"; 
$LANG['job'][49]="Nueva tarea"; 
$LANG['job'][50]="Sin tareas para esta incidencia"; 
$LANG['job'][51]="Aprobación de la solución"; 
$LANG['job'][52]="Actualizar una tarea"; 
$LANG['job'][53]="Supresión de una tarea"; 
$LANG['job'][54]="Sin una respuesta la incidencia se borrará después de"; 

$LANG['joblist'][0]="Estado"; 
$LANG['joblist'][1]="Sólo los míos"; 
$LANG['joblist'][2]="Prioridad"; 
$LANG['joblist'][3]="Los míos y los de mis grupos"; 
$LANG['joblist'][4]="Asignada a"; 
$LANG['joblist'][6]="Descripción"; 
$LANG['joblist'][7]="Nueva incidencia para este item..."; 
$LANG['joblist'][8]="No se han hallado incidencias."; 
$LANG['joblist'][9]="Nueva"; 
$LANG['joblist'][10]="Cerrada (resuelta)"; 
$LANG['joblist'][11]="Abierta el"; 
$LANG['joblist'][12]="Cerrada el"; 
$LANG['joblist'][13]="Incidencias a procesar"; 
$LANG['joblist'][14]="Solucionado el"; 
$LANG['joblist'][16]="No hay incidencias pendientes."; 
$LANG['joblist'][17]="Cerrada (no resuelta)"; 
$LANG['joblist'][18]="En curso (asignada)"; 
$LANG['joblist'][19]="En curso (planificada)"; 
$LANG['joblist'][21]="En curso"; 
$LANG['joblist'][26]="En espera"; 
$LANG['joblist'][27]="Correo para el seguimiento"; 
$LANG['joblist'][28]="Incidencia sobre los elementos de red"; 
$LANG['joblist'][29]="Urgencia"; 
$LANG['joblist'][30]="Impacto"; 
$LANG['joblist'][32]="Resuelto"; 
$LANG['joblist'][33]="Cerrado"; 
$LANG['joblist'][34]="Sin resolver"; 
$LANG['joblist'][35]="Sin cerrar"; 
$LANG['joblist'][36]="Valor del estado en la base de datos"; 

$LANG['jobresolution'][1]="Solución"; 
$LANG['jobresolution'][3]="Solución aprobada"; 
$LANG['jobresolution'][4]="Solución rechazada"; 
$LANG['jobresolution'][5]="En el caso de rechazar la solución debes indicar un motivo"; 

$LANG['knowbase'][1]="Preguntas Frecuentes"; 
$LANG['knowbase'][5]="Colocar este artículo en las Preguntas Frecuentes públicas"; 
$LANG['knowbase'][6]="Seleccionar una categoría para este artículo:"; 
$LANG['knowbase'][7]="Retirar este artículo de las Preguntas Frecuentes públicas"; 
$LANG['knowbase'][8]="Modificar este artículo"; 
$LANG['knowbase'][9]="Borrar este artículo"; 
$LANG['knowbase'][10]="Este artículo forma parte de las Preguntas Frecuentes públicas"; 
$LANG['knowbase'][11]="Este artículo no forma parte de las Preguntas Frecuentes públicas"; 
$LANG['knowbase'][12]="Raíz"; 
$LANG['knowbase'][13]="Nombre de la categoría"; 
$LANG['knowbase'][14]="Tema"; 
$LANG['knowbase'][15]="Contenido"; 
$LANG['knowbase'][24]="Acceder a las Preguntas Frecuentes"; 
$LANG['knowbase'][26]="Vistas"; 
$LANG['knowbase'][27]="El"; 
$LANG['knowbase'][29]="Artículos recientes"; 
$LANG['knowbase'][30]="Artículos más consultados"; 

$LANG['ldap'][0]="Importación masiva de usuarios desde un servidor"; 
$LANG['ldap'][1]="Sincronización de los usuarios ya importados"; 
$LANG['ldap'][2]="Importación de usuarios nuevos"; 
$LANG['ldap'][3]="No hay usuarios que importar"; 
$LANG['ldap'][4]="Elección del servidor LDAP"; 
$LANG['ldap'][5]="Elija el servidor LDAP del que se importarán los usuarios"; 
$LANG['ldap'][6]="Imposible conectar con el servidor LDAP"; 
$LANG['ldap'][7]="No hay ningún servidor LDAP definido en GLPI"; 
$LANG['ldap'][8]="Cuidado: La respuesta excede el límite del LDAP. Los resultados son parciales"; 
$LANG['ldap'][9]="Prueba de conexión con el servidor LDAP"; 
$LANG['ldap'][12]="Sincronización"; 
$LANG['ldap'][13]="en LDAP"; 
$LANG['ldap'][14]="en GLPI"; 
$LANG['ldap'][15]="Sincronizar"; 
$LANG['ldap'][16]="Configuración previa"; 
$LANG['ldap'][17]="Directorio Activo"; 
$LANG['ldap'][18]="Lista de réplicas de LDAP"; 
$LANG['ldap'][19]="Replicar"; 
$LANG['ldap'][20]="Añadir una réplica LDAP"; 
$LANG['ldap'][21]="Servidor principal"; 
$LANG['ldap'][22]="Réplica(s)"; 
$LANG['ldap'][23]="Importación masiva de grupos desde un servidor LDAP"; 
$LANG['ldap'][24]="Importación de nuevos grupos"; 
$LANG['ldap'][25]="Ningún grupo para ser importado"; 
$LANG['ldap'][30]="Tratamiento de los alias LDAP"; 
$LANG['ldap'][31]="Nunca (defecto)"; 
$LANG['ldap'][32]="Siempre"; 
$LANG['ldap'][33]="Desreferenciado durante la búsqueda"; 
$LANG['ldap'][34]="Desreferenciado durante la localización"; 
$LANG['ldap'][35]="Importar un usuario"; 
$LANG['ldap'][36]="Ningún directorio asociado con la entidad"; 
$LANG['ldap'][38]="Criterios de búsqueda para los usuarios"; 
$LANG['ldap'][39]="Experto"; 
$LANG['ldap'][40]="Simple"; 
$LANG['ldap'][41]="Cambiar"; 
$LANG['ldap'][42]="Ningún directorio seleccionado"; 
$LANG['ldap'][43]="No hay usuarios para sincronizar"; 
$LANG['ldap'][44]="Servidor por defecto"; 
$LANG['ldap'][45]="Acción cuando un usuario es eliminado de LDAP"; 
$LANG['ldap'][46]="Eliminar los permisos y grupos (dinámicos)"; 
$LANG['ldap'][47]="Enviar a la papelera"; 
$LANG['ldap'][48]="Usuario borrado de LDAP"; 
$LANG['ldap'][49]="Ver usuarios añadidos desde"; 
$LANG['ldap'][50]="Ver usuarios actualizados desde"; 
$LANG['ldap'][52]="Menos de"; 
$LANG['ldap'][53]="Mas de"; 
$LANG['ldap'][54]="Activar el filtro por fecha"; 
$LANG['ldap'][55]="Desactivar el filtro por fecha"; 
$LANG['ldap'][56]="Semanas"; 

$LANG['links'][1]="Enlace o nombre de fichero"; 
$LANG['links'][4]="Tipo de materiales asociados"; 
$LANG['links'][6]="Tags válidos"; 
$LANG['links'][7]="No hay enlaces definidos"; 
$LANG['links'][9]="Contenido del fichero"; 

$LANG['log'][1]="sistema"; 
$LANG['log'][16]="planificación"; 
$LANG['log'][18]="componentes"; 
$LANG['log'][20]="añadir el elemento"; 
$LANG['log'][21]="modificación del elemento"; 
$LANG['log'][22]="borrado del elemento"; 
$LANG['log'][23]="restauración del elemento"; 
$LANG['log'][24]="purga del elemento"; 
$LANG['log'][26]="desconexión del elemento"; 
$LANG['log'][27]="conexión del elemento"; 
$LANG['log'][28]="modificación de componentes"; 
$LANG['log'][29]="aprobación/rehusado de la solución"; 
$LANG['log'][30]="Asociación de un tipo"; 
$LANG['log'][31]="borrado de un tipo"; 
$LANG['log'][32]="añadido enlace con un elemento"; 
$LANG['log'][33]="borrado de enlace con un elemento"; 
$LANG['log'][34]="añadido un enlace con proveedor"; 
$LANG['log'][35]="borrado de enlace con proveedor"; 
$LANG['log'][40]="Conexión del IP"; 
$LANG['log'][41]="fallo de conexión"; 
$LANG['log'][42]="Reserva"; 
$LANG['log'][44]="Titulado"; 
$LANG['log'][45]="Correcta"; 
$LANG['log'][46]="Fallida"; 
$LANG['log'][48]="añadir usuario al grupo"; 
$LANG['log'][49]="borrado de usuario en el grupo"; 
$LANG['log'][55]="Conexión"; 
$LANG['log'][59]="Cron"; 
$LANG['log'][60]="desglobalización del item"; 
$LANG['log'][61]="añadido un usuario a la entidad"; 
$LANG['log'][62]="borrado de un usuario de la entidad"; 
$LANG['log'][64]="modificación del campo"; 
$LANG['log'][65]="regla"; 
$LANG['log'][66]="Seguridad"; 
$LANG['log'][67]="modificación de las notas"; 
$LANG['log'][70]="añadido un puerto de red"; 
$LANG['log'][71]="añadidos varios puertos de red"; 
$LANG['log'][73]="eliminación de un puerto de red"; 
$LANG['log'][74]="eliminación de varios puertos de red"; 
$LANG['log'][75]="puerto de red movido"; 
$LANG['log'][77]="vlan asignada a puerto de red"; 
$LANG['log'][78]="asignación de una VLAN a varios puertos de red"; 
$LANG['log'][79]="vlan no asignada a puerto de red"; 
$LANG['log'][80]="quitada la asignación de vlan a varios puertos de red"; 
$LANG['log'][82]="añadiendo versión"; 
$LANG['log'][83]="modificación de la versión"; 
$LANG['log'][84]="eliminación de la versión"; 
$LANG['log'][85]="añadiendo licencia"; 
$LANG['log'][86]="modificación de la licencia"; 
$LANG['log'][87]="eliminación de la licencia"; 
$LANG['log'][88]="añadiendo cartuchos"; 
$LANG['log'][89]="añadiendo consumibles"; 
$LANG['log'][90]="exclusión de un cartucho"; 
$LANG['log'][91]="exclusión de un consumible"; 
$LANG['log'][92]="restauración de un cartucho"; 
$LANG['log'][93]="restauración de un consumible"; 
$LANG['log'][94]="actualización de cartuchos"; 
$LANG['log'][95]="instalación de cartuchos"; 
$LANG['log'][96]="desinstalación de cartuchos"; 
$LANG['log'][97]="liberación de un consumible por el usuario"; 
$LANG['log'][98]="adjuntar un elemento"; 
$LANG['log'][99]="modificación de un elemento"; 
$LANG['log'][100]="eliminación de un elemento"; 

$LANG['login'][0]="Última conexión"; 
$LANG['login'][1]="Volver a conectarse"; 
$LANG['login'][2]="LDAP"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Acceso denegado"; 
$LANG['login'][6]="Usuario"; 
$LANG['login'][7]="Contraseña"; 
$LANG['login'][8]="Usuario o contraseña vacíos"; 
$LANG['login'][9]="Aún no se ha identificado"; 
$LANG['login'][10]="Identificación"; 
$LANG['login'][11]="Usuario no autorizado a conectarse"; 
$LANG['login'][12]="Usuario o contraseña erróneos"; 
$LANG['login'][13]="Contraseña vacía"; 
$LANG['login'][14]="Usuario desconocido"; 
$LANG['login'][15]="Usuario no encontrado o encontrados varios usuarios"; 
$LANG['login'][16]="Fallo en la identificación LDAP"; 
$LANG['login'][18]="Base interna de GLPI"; 
$LANG['login'][20]="No tiene acceso a esta aplicación. Su cuenta ha sido desactivada o borrada."; 
$LANG['login'][21]="Prueba de conexión con el servidor IMAP/POP"; 
$LANG['login'][22]="Prueba correcta"; 
$LANG['login'][23]="Prueba fallida"; 
$LANG['login'][24]="Fecha de la última actualización"; 
$LANG['login'][25]="No tiene permisos para conectarse a esta aplicación"; 
$LANG['login'][26]="Debe activar Javascript en su navegador"; 
$LANG['login'][27]="Debe aceptar cookies para acceder a la aplicación"; 
$LANG['login'][30]="Cambiar el método de identificación"; 
$LANG['login'][31]="Identificación sobre LDAP"; 
$LANG['login'][32]="Identificación sobre la base de datos de GLPI"; 
$LANG['login'][33]="Identificación sobre el servidor POP/IMAP"; 

$LANG['mailgate'][0]="Servidor de correo POP3"; 
$LANG['mailgate'][2]="Recuperar ahora"; 
$LANG['mailgate'][3]="Número de mensajes disponibles y recuperados"; 
$LANG['mailgate'][4]="La extensión mbstring no está disponible. Tenga cuidado con los juegos de caracteres que utiliza."; 
$LANG['mailgate'][5]="Fichero adjunto no válido"; 
$LANG['mailgate'][6]="Fichero adjunto demasiado grande"; 
$LANG['mailgate'][7]="Servidor de correo POP: tamaño máximo de cada fichero adjunto (0 : sin límite)"; 
$LANG['mailgate'][9]="Su correo no puede ser tratado. \n Contactar con el administrador si el problema persiste"; 
$LANG['mailgate'][10]="Correo rechazado"; 
$LANG['mailgate'][11]="Proceso de importación de correos electrónicos"; 
$LANG['mailgate'][12]="No se puede asociar el correo electrónico a una entidad"; 
$LANG['mailgate'][13]="Razón del rechazo"; 
$LANG['mailgate'][14]="La dirección de correo no existe. Imposible importarla"; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="======================================================================"; 
$LANG['mailing'][4]="Seguimiento(s) efectuado(s)"; 
$LANG['mailing'][5]="Descripción de la incidencia"; 
$LANG['mailing'][10]="Nuevo seguimiento para esta incidencia"; 
$LANG['mailing'][12]="Asignación de incidencia"; 
$LANG['mailing'][14]="Modificación de la categoría de la incidencia"; 
$LANG['mailing'][15]="Modificación de la prioridad de la incidencia"; 
$LANG['mailing'][17]="Modificación del material involucrado en la incidencia"; 
$LANG['mailing'][18]="Modificación del autor de la incidencia"; 
$LANG['mailing'][19]="Nueva reserva"; 
$LANG['mailing'][20]="Modificación del grupo de la incidencia"; 
$LANG['mailing'][21]="Modificación del origen de la incidencia"; 
$LANG['mailing'][23]="Modificación de reserva"; 
$LANG['mailing'][26]="Documento añadido :"; 
$LANG['mailing'][27]="Modificación del estado de la incidencia"; 
$LANG['mailing'][29]="Anular la reserva"; 
$LANG['mailing'][30]="Modificación de incidencia"; 
$LANG['mailing'][31]="Este es el mensaje de prueba de envío de email"; 
$LANG['mailing'][32]="Prueba de correo"; 
$LANG['mailing'][33]="Alerta de cartuchos"; 
$LANG['mailing'][35]="Umbral de alerta alcanzado para el tipo de consumibles:"; 
$LANG['mailing'][36]="Alerta de consumibles"; 
$LANG['mailing'][37]="Contrato en período de preaviso:"; 
$LANG['mailing'][39]="Alerta de contratos"; 
$LANG['mailing'][40]="Material llegado a caducidad de garantía:"; 
$LANG['mailing'][41]="Alerta de datos financieros"; 
$LANG['mailing'][42]="Modificación del coste por hora"; 
$LANG['mailing'][43]="Modificación del coste fijo"; 
$LANG['mailing'][44]="Modificación del coste del material"; 
$LANG['mailing'][45]="Modificación del título de la incidencia"; 
$LANG['mailing'][46]="Modificación de la descripción de la incidencia"; 
$LANG['mailing'][47]="Error en el envío del correo"; 
$LANG['mailing'][48]="Cambio de la fecha de apertura"; 
$LANG['mailing'][49]="Cambio de la fecha de cierre"; 
$LANG['mailing'][50]="Modificación del receptor de la incidencia"; 
$LANG['mailing'][51]="Licencia expirada :"; 
$LANG['mailing'][53]="Cambio de la solución"; 
$LANG['mailing'][54]="Fecha de expiración"; 
$LANG['mailing'][100]="No hay categoría asignada"; 
$LANG['mailing'][101]="Seguimiento por correo activado"; 
$LANG['mailing'][102]="Seguimiento por correo desactivado"; 
$LANG['mailing'][104]="Duración de la incidencia"; 
$LANG['mailing'][105]="No asignada"; 
$LANG['mailing'][107]="No hay material involucrado"; 
$LANG['mailing'][109]="Sin grupo"; 
$LANG['mailing'][110]="Correo electrónico no válido"; 
$LANG['mailing'][113]="Modelos de notificaciones"; 
$LANG['mailing'][114]="Cuerpo del mensaje"; 
$LANG['mailing'][115]="Cuerpo del correo"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="texto"; 
$LANG['mailing'][118]="Correo electrónico"; 
$LANG['mailing'][119]="Evento"; 
$LANG['mailing'][120]="Modo de notificación"; 
$LANG['mailing'][121]="Destinatarios"; 
$LANG['mailing'][122]="Tarea(s) ejecutada(s)"; 
$LANG['mailing'][123]="Incidencia resuelta"; 
$LANG['mailing'][124]="Añadir una nueva traducción"; 
$LANG['mailing'][125]="Tradución por defecto"; 
$LANG['mailing'][126]="Plantilla de traducción"; 
$LANG['mailing'][127]="Clausura de la incidencia"; 
$LANG['mailing'][128]="dejar el campo vacío para una generación a partir del HTML"; 
$LANG['mailing'][129]="Supresión de una incidencia"; 
$LANG['mailing'][130]="De"; 
$LANG['mailing'][131]="Destinatario"; 
$LANG['mailing'][132]="Cabecera del correo"; 
$LANG['mailing'][133]="Borrar correo(s)"; 
$LANG['mailing'][134]="Actualización de seguimiento"; 
$LANG['mailing'][135]="Borrado de seguimiento"; 
$LANG['mailing'][136]="Fin de la reserva"; 
$LANG['mailing'][137]="Usuario del material"; 
$LANG['mailing'][138]="Listado de los tags disponibles"; 
$LANG['mailing'][139]="Etiqueta"; 
$LANG['mailing'][140]="TAG"; 
$LANG['mailing'][141]="Seguimientos"; 
$LANG['mailing'][142]="Tareas"; 
$LANG['mailing'][143]="Validaciones"; 
$LANG['mailing'][144]="Histórico"; 
$LANG['mailing'][145]="Lista de valores"; 
$LANG['mailing'][146]="valor único"; 
$LANG['mailing'][147]="Valor(es) posible(s)"; 

$LANG['Menu'][0]="Ordenadores"; 
$LANG['Menu'][1]="Electrónica de red"; 
$LANG['Menu'][2]="Impresoras"; 
$LANG['Menu'][3]="Monitores"; 
$LANG['Menu'][4]="Software"; 
$LANG['Menu'][5]="Seguimientos"; 
$LANG['Menu'][6]="Informes"; 
$LANG['Menu'][11]="Preferencias"; 
$LANG['Menu'][12]="Mantenimiento"; 
$LANG['Menu'][13]="Estadísticas"; 
$LANG['Menu'][14]="Usuarios"; 
$LANG['Menu'][15]="Administración"; 
$LANG['Menu'][16]="Periféricos"; 
$LANG['Menu'][17]="Reservas"; 
$LANG['Menu'][18]="Utilidades"; 
$LANG['Menu'][19]="Base de conocimiento"; 
$LANG['Menu'][20]="Preguntas Frecuentes"; 
$LANG['Menu'][21]="Cartuchos"; 
$LANG['Menu'][22]="Contactos"; 
$LANG['Menu'][23]="Proveedores"; 
$LANG['Menu'][24]="Datos financieros"; 
$LANG['Menu'][25]="Contratos"; 
$LANG['Menu'][26]="Gestión"; 
$LANG['Menu'][27]="Documentos"; 
$LANG['Menu'][28]="Estados"; 
$LANG['Menu'][29]="Planificación"; 
$LANG['Menu'][30]="Registros"; 
$LANG['Menu'][31]="CAU (Centro de Atención a Usuarios)"; 
$LANG['Menu'][32]="Consumibles"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="Teléfonos"; 
$LANG['Menu'][35]="Perfiles"; 
$LANG['Menu'][36]="Grupos"; 
$LANG['Menu'][37]="Entidades"; 
$LANG['Menu'][38]="Inventario"; 
$LANG['Menu'][39]="Servidores de correo"; 
$LANG['Menu'][40]="Marcadores"; 
$LANG['Menu'][41]="Permisos"; 

$LANG['monitors'][14]="Micrófono"; 
$LANG['monitors'][15]="Altavoces"; 
$LANG['monitors'][18]="Opciones"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Tamaño"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Peana"; 

$LANG['networking'][4]="Puerto de red"; 
$LANG['networking'][5]="RAM (MB)"; 
$LANG['networking'][6]="Puertos de red"; 
$LANG['networking'][13]="puertos de red encontrados"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Conectado a"; 
$LANG['networking'][19]="Añadir un puerto..."; 
$LANG['networking'][21]="Número de puerto"; 
$LANG['networking'][25]="sobre"; 
$LANG['networking'][37]="Puerto(s) encontrado(s)"; 
$LANG['networking'][44]="El puerto"; 
$LANG['networking'][46]="Añadir varios puertos..."; 
$LANG['networking'][47]="De"; 
$LANG['networking'][48]="A"; 
$LANG['networking'][51]="Roseta"; 
$LANG['networking'][55]="Asociar una VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Elija una dirección MAC de la lista o especifíquela aquí debajo."; 
$LANG['networking'][58]="Borrar una VLAN"; 
$LANG['networking'][59]="IP de enlace"; 
$LANG['networking'][60]="Máscara"; 
$LANG['networking'][61]="Subred"; 

$LANG['ocsconfig'][1]="Usuarios de la base de datos OCSNG"; 
$LANG['ocsconfig'][2]="Servidor OCSNG"; 
$LANG['ocsconfig'][3]="Contraseña de usuario OCSweb"; 
$LANG['ocsconfig'][4]="Nombre de la base de datos OCSNG"; 
$LANG['ocsconfig'][5]="Opciones de importación"; 
$LANG['ocsconfig'][6]="Ignorar la importación desde OCSNG"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Excluir las siguientes etiquetas (separador $, nada para todas)"; 
$LANG['ocsconfig'][10]="Importación global"; 
$LANG['ocsconfig'][11]="No importar"; 
$LANG['ocsconfig'][12]="Importación única"; 
$LANG['ocsconfig'][13]="Importación única: todo se importa tal cual"; 
$LANG['ocsconfig'][14]="Importación global: todo se importa pero el material se gestiona de manera global (sin duplicados)"; 
$LANG['ocsconfig'][15]="No importar: GLPI no importará estos elementos"; 
$LANG['ocsconfig'][16]="Estado predeterminado"; 
$LANG['ocsconfig'][17]="Limitar la importación a los tags siguientes (separador $; nada, para todos)"; 
$LANG['ocsconfig'][18]="Asegúrese de haber gestionado correctamente los duplicados en OCSNG"; 
$LANG['ocsconfig'][19]="Importación única basada en el número de serie"; 
$LANG['ocsconfig'][27]="Información general"; 
$LANG['ocsconfig'][36]="Modems"; 
$LANG['ocsconfig'][37]="Puertos"; 
$LANG['ocsconfig'][38]="Utilizar el diccionario de software de OCS"; 
$LANG['ocsconfig'][39]="TAG OCSNG"; 
$LANG['ocsconfig'][40]="Cantidad de elementos a sincronizar mediante cron"; 
$LANG['ocsconfig'][41]="Registro de Windows"; 
$LANG['ocsconfig'][43]="Información administrativa de OCSNG"; 
$LANG['ocsconfig'][48]="Comportamiento durante la desconexión"; 
$LANG['ocsconfig'][49]="Papelera"; 
$LANG['ocsconfig'][50]="Eliminación"; 
$LANG['ocsconfig'][52]="Enlace automático de ordenadores"; 
$LANG['ocsconfig'][53]="Activar los enlaces automáticos"; 
$LANG['ocsconfig'][54]="Criterios de existencia de un ordenador"; 
$LANG['ocsconfig'][55]="Buscar los ordenadores GLPI con el estado"; 
$LANG['ocsconfig'][56]="vacío"; 
$LANG['ocsconfig'][57]="igual"; 
$LANG['ocsconfig'][58]="El enlace une automáticamente un ordenador GLPI con uno de OCS.<br>Esta opción se tiene en cuenta durante el enlace manual y los scripts de sincronización."; 
$LANG['ocsconfig'][59]="URL de la consola de OCSNG"; 

$LANG['ocsng'][0]="Inventario OCS NG"; 
$LANG['ocsng'][1]="Sincronización de ordenadores ya importados"; 
$LANG['ocsng'][2]="Importación de ordenadores nuevos"; 
$LANG['ocsng'][3]="Limpieza de enlaces GLPI/OCSNG"; 
$LANG['ocsng'][4]="Enlazar ordenadores nuevos a ordenadores existentes"; 
$LANG['ocsng'][5]="Importar ordenadores nuevos"; 
$LANG['ocsng'][6]="Actualización automática"; 
$LANG['ocsng'][7]="Importado desde OCSNG"; 
$LANG['ocsng'][8]="Importación correcta"; 
$LANG['ocsng'][9]="No hay nuevos ordenadores para importar"; 
$LANG['ocsng'][10]="Ordenadores actualizados en OCSNG"; 
$LANG['ocsng'][11]="Actualización de ordenadores"; 
$LANG['ocsng'][12]="No hay nuevos ordenadores para actualizar"; 
$LANG['ocsng'][13]="Fecha de importación a GLPI"; 
$LANG['ocsng'][14]="Fecha del último inventario OCSNG"; 
$LANG['ocsng'][15]="No hay campos bloqueados"; 
$LANG['ocsng'][16]="Campos bloqueados"; 
$LANG['ocsng'][18]="Conexión correcta con la base de datos OCSNG"; 
$LANG['ocsng'][19]="Versión y configuración OCSNG válidas"; 
$LANG['ocsng'][20]="Versión de OCSNG no válida: se necesita RC3"; 
$LANG['ocsng'][21]="No se logró la conexión con la base de datos OCSNG"; 
$LANG['ocsng'][22]="¡Cuidado! Los datos importados (vea su configuración) sustituirán a los existentes"; 
$LANG['ocsng'][23]="Importación imposible, el ordenador destino de GLPI ya está enlazado a un elemento de OCSNG"; 
$LANG['ocsng'][24]="Forzar la sincronización"; 
$LANG['ocsng'][26]="Elija un servidor OCSNG"; 
$LANG['ocsng'][27]="No se ha definido ningún servidor OCS"; 
$LANG['ocsng'][29]="Servidor OCSNG"; 
$LANG['ocsng'][30]="Monitores bloqueados"; 
$LANG['ocsng'][32]="Periféricos bloqueados"; 
$LANG['ocsng'][34]="Impresoras bloqueadas"; 
$LANG['ocsng'][36]="Entidad de destino"; 
$LANG['ocsng'][37]="Activar la vista preliminar"; 
$LANG['ocsng'][38]="Desactivar la vista preliminar"; 
$LANG['ocsng'][40]="¿Cumple la regla?"; 
$LANG['ocsng'][41]="Modo de importación manual"; 
$LANG['ocsng'][42]="La configuración de OCSNG no es correcta. Debe activar TRACE_DELETED."; 
$LANG['ocsng'][43]="Acceso denegado a la base de datos de OCS. Es necesario tener permiso de escritura sobre hardware.CHECKSUM necesario."; 
$LANG['ocsng'][44]="Acceso denegado a la base de datos de OCSNG. Es necesario tener permiso de borrado sobre deleted_equiv."; 
$LANG['ocsng'][45]="ID OCS"; 
$LANG['ocsng'][46]="Borrado de OCSNG"; 
$LANG['ocsng'][47]="Enlazado con un ordenador de OCSNG"; 
$LANG['ocsng'][48]="El ordenador ha cambiado de identificador OCSNG (ID)"; 
$LANG['ocsng'][49]="Agente"; 
$LANG['ocsng'][50]="IPs bloqueadas"; 
$LANG['ocsng'][52]="Software bloqueado"; 
$LANG['ocsng'][54]="Material tirado a la papelera por la sincronización OCS"; 
$LANG['ocsng'][55]="Volumen(es) bloqueado(s)"; 
$LANG['ocsng'][57]="Interfaz OCSNG"; 

$LANG['pager'][1]="hasta"; 
$LANG['pager'][2]="desde"; 
$LANG['pager'][3]="de"; 
$LANG['pager'][4]="Mostrar"; 
$LANG['pager'][5]="elementos"; 

$LANG['peripherals'][18]="Marca"; 
$LANG['peripherals'][31]="Gestión global"; 
$LANG['peripherals'][32]="Gestión individual"; 
$LANG['peripherals'][33]="Tipo de gestión"; 

$LANG['phones'][18]="Marca"; 
$LANG['phones'][36]="Alimentación"; 
$LANG['phones'][38]="Casco"; 
$LANG['phones'][39]="Altavoz"; 
$LANG['phones'][40]="Cantidad de líneas"; 

$LANG['planning'][0]="El técnico solicitado ya tiene un servicio previsto para este horario."; 
$LANG['planning'][1]="Error en las fechas. La fecha inicial es posterior a la fecha final"; 
$LANG['planning'][5]="Día"; 
$LANG['planning'][6]="Semana"; 
$LANG['planning'][8]="Servicio"; 
$LANG['planning'][9]="Por"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Descargar calendario en formato Ical"; 
$LANG['planning'][13]="Sincronización Webcal://"; 
$LANG['planning'][14]="Mes"; 
$LANG['planning'][15]="Su planificación"; 
$LANG['planning'][16]="Información"; 
$LANG['planning'][17]="Pendiente"; 
$LANG['planning'][18]="Terminado"; 

$LANG['plugins'][0]="Lista de Plugins"; 
$LANG['plugins'][2]="Instalado / no configurado"; 
$LANG['plugins'][3]="Instalado / no activado"; 
$LANG['plugins'][4]="Error / a limpiar"; 
$LANG['plugins'][5]="Función(es) inexistente(s)"; 
$LANG['plugins'][6]="A actualizar"; 
$LANG['plugins'][7]="Ningún plugin instalado"; 
$LANG['plugins'][8]="Ver listado de plugins"; 
$LANG['plugins'][9]="Autores"; 
$LANG['plugins'][10]="Plugin incompatible con esta versión de GLPI"; 

$LANG['printers'][14]="Serie"; 
$LANG['printers'][15]="Paralelo"; 
$LANG['printers'][18]="Puertos"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="Inhalámbrica"; 
$LANG['printers'][30]="Contador de página inicial"; 
$LANG['printers'][31]="Páginas impresas"; 

$LANG['profiles'][0]="Permiso global"; 
$LANG['profiles'][1]="Permiso local"; 
$LANG['profiles'][2]="Interfaz asociado al perfíl"; 
$LANG['profiles'][4]="Añadir seguimiento a las incidencias de mi(s) grupo(s)"; 
$LANG['profiles'][5]="Abrir una incidencia"; 
$LANG['profiles'][6]="Añadir un seguimiento a las incidencias (autor)"; 
$LANG['profiles'][7]="Ver todas las incidencias"; 
$LANG['profiles'][8]="Ver todo el seguimiento (público y privado)"; 
$LANG['profiles'][9]="Ver el seguimiento público"; 
$LANG['profiles'][10]="Lectura"; 
$LANG['profiles'][11]="Escritura"; 
$LANG['profiles'][12]="Sin acceso"; 
$LANG['profiles'][13]="Perfil predeterminado"; 
$LANG['profiles'][14]="Borrar una incidencia"; 
$LANG['profiles'][15]="Añadir un seguimiento a todas las incidencias"; 
$LANG['profiles'][16]="Estar a cargo de una incidencia"; 
$LANG['profiles'][17]="Quitar una incidencia"; 
$LANG['profiles'][18]="Modificar una incidencia"; 
$LANG['profiles'][19]="Asignar una incidencia"; 
$LANG['profiles'][20]="Ver planificación personal"; 
$LANG['profiles'][21]="Ver todas las planificaciones"; 
$LANG['profiles'][22]="Perfil"; 
$LANG['profiles'][23]="Administración de reservas"; 
$LANG['profiles'][24]="Cambiar la contraseña"; 
$LANG['profiles'][26]="Ver las incidencias creadas por grupo asociado"; 
$LANG['profiles'][27]="Ver los materiales de los grupos asociados"; 
$LANG['profiles'][28]="Recursivo"; 
$LANG['profiles'][29]="Dinámico"; 
$LANG['profiles'][30]="Ver la información OCSNG"; 
$LANG['profiles'][31]="Sincronización manual con OCSNG"; 
$LANG['profiles'][32]="Ver las incidencias asignadas (personal + grupo asociado)"; 
$LANG['profiles'][33]="No se han encontrado usuarios"; 
$LANG['profiles'][34]="Leyenda"; 
$LANG['profiles'][35]="Modificar todos los seguimientos"; 
$LANG['profiles'][36]="Ver la planificación de las personas de mis grupos"; 
$LANG['profiles'][37]="Entidad por defecto"; 
$LANG['profiles'][38]="Visibilidad"; 
$LANG['profiles'][39]="Assignación"; 
$LANG['profiles'][40]="Actualizar"; 
$LANG['profiles'][41]="Crear"; 
$LANG['profiles'][42]="Asociación"; 
$LANG['profiles'][43]="Método de autenticación y sincronización de los usuarios"; 
$LANG['profiles'][44]="Modificar la prioridad"; 
$LANG['profiles'][45]="Agregar una tarea a todas las incidencias"; 
$LANG['profiles'][46]="Editar todas las tareas"; 
$LANG['profiles'][47]="Adición de usuarios de una fuente externa"; 
$LANG['profiles'][48]="Solicitud de validación de incidencia"; 
$LANG['profiles'][49]="Validar una incidencia"; 

$LANG['registry'][1]="Sección"; 
$LANG['registry'][2]="Ruta"; 
$LANG['registry'][3]="Clave/valor"; 
$LANG['registry'][4]="Claves de registro encontradas"; 
$LANG['registry'][5]="No se ha encontrado ninguna clave del Registro de Windows"; 
$LANG['registry'][6]="Nombre OCSNG"; 

$LANG['reminder'][0]="Notas personales"; 
$LANG['reminder'][1]="Notas públicas"; 
$LANG['reminder'][6]="Nueva nota"; 
$LANG['reminder'][9]="Texto"; 
$LANG['reminder'][12]="Añadir a la lista"; 
$LANG['reminder'][15]="Sin título"; 
$LANG['reminder'][16]="Notas globales"; 

$LANG['reports'][0]="Seleccionar un informe"; 
$LANG['reports'][4]="Lista del material bajo contrato"; 
$LANG['reports'][11]="Material bajo contrato"; 
$LANG['reports'][12]="Tipo de material"; 
$LANG['reports'][13]="Fechas"; 
$LANG['reports'][15]="Mostrar informe"; 
$LANG['reports'][19]="Contacto"; 
$LANG['reports'][26]="Informe predeterminado"; 
$LANG['reports'][27]="Por contratos"; 
$LANG['reports'][28]="Por años"; 
$LANG['reports'][33]="Informe de red"; 
$LANG['reports'][36]="Dispositivos conectados"; 
$LANG['reports'][37]="Rosetas"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="Por lugar"; 
$LANG['reports'][41]="Por switch"; 
$LANG['reports'][42]="Por roseta"; 
$LANG['reports'][46]="puerto del switch"; 
$LANG['reports'][47]="Puerto del dispositivo"; 
$LANG['reports'][49]="Informe de red por switch"; 
$LANG['reports'][51]="Informe de red por roseta"; 
$LANG['reports'][52]="switch"; 
$LANG['reports'][54]="Informe de red por lugar"; 
$LANG['reports'][57]="Lista de materiales"; 
$LANG['reports'][58]="Informe de los materiales por años"; 
$LANG['reports'][60]="Fecha de apertura"; 
$LANG['reports'][61]="Fecha de cierre"; 
$LANG['reports'][62]="Datos financieros de material inventariado"; 
$LANG['reports'][63]="Otros datos financieros (licencias, consumibles, cartuchos)"; 
$LANG['reports'][64]="Fecha de resolución"; 

$LANG['reservation'][1]="Material reservable"; 
$LANG['reservation'][2]="Material no disponible temporalmente"; 
$LANG['reservation'][3]="Haga clic para que quede no disponible"; 
$LANG['reservation'][5]="Haga clic para que quede disponible"; 
$LANG['reservation'][6]="No autorizar el préstamo"; 
$LANG['reservation'][7]="Autorizar el préstamo"; 
$LANG['reservation'][8]="Reservar"; 
$LANG['reservation'][9]="Reservar un material"; 
$LANG['reservation'][16]="Hasta"; 
$LANG['reservation'][17]="Desde"; 
$LANG['reservation'][18]="El material solicitado ya está reservado para este horario."; 
$LANG['reservation'][20]="Volver al calendario"; 
$LANG['reservation'][21]="Ver las reservas"; 
$LANG['reservation'][22]="Modificar el comentario"; 
$LANG['reservation'][25]="Todos los materiales en préstamo"; 
$LANG['reservation'][27]="Periodicidad"; 
$LANG['reservation'][28]="Por semana"; 
$LANG['reservation'][29]="Por día"; 
$LANG['reservation'][30]="veces"; 
$LANG['reservation'][31]="Por"; 
$LANG['reservation'][35]="Reservas en curso y futuras"; 
$LANG['reservation'][36]="Reservas pasadas"; 
$LANG['reservation'][37]="No hay reservas"; 
$LANG['reservation'][38]="¿Está seguro de querer volver este elemento no reservable?"; 
$LANG['reservation'][39]="Esto borrará todas las reservas en curso."; 
$LANG['reservation'][40]="Equipos con reserva en los que expira hoy"; 

$LANG['rulesengine'][0]="es"; 
$LANG['rulesengine'][1]="no es"; 
$LANG['rulesengine'][2]="contiene"; 
$LANG['rulesengine'][3]="no contiene"; 
$LANG['rulesengine'][4]="comienza por"; 
$LANG['rulesengine'][5]="terminado por"; 
$LANG['rulesengine'][6]="Criterios"; 
$LANG['rulesengine'][7]="Acciones"; 
$LANG['rulesengine'][8]="Gestión de reglas"; 
$LANG['rulesengine'][9]="Tipo de emparejamiento"; 
$LANG['rulesengine'][10]="Posición"; 
$LANG['rulesengine'][11]="Tipo de acción"; 
$LANG['rulesengine'][12]="Campos"; 
$LANG['rulesengine'][13]="Valor"; 
$LANG['rulesengine'][14]="Condición"; 
$LANG['rulesengine'][15]="Motivo"; 
$LANG['rulesengine'][16]="Criterio"; 
$LANG['rulesengine'][17]="Reglas"; 
$LANG['rulesengine'][18]="Reglas de asignación de un ordenador a una entidad"; 
$LANG['rulesengine'][19]="Reglas de asignación de entidad y de permisos"; 
$LANG['rulesengine'][20]="Reglas heredadas"; 
$LANG['rulesengine'][21]="Reglas de subentidades"; 
$LANG['rulesengine'][22]="Asignar"; 
$LANG['rulesengine'][23]="Reglas locales"; 
$LANG['rulesengine'][24]="Elección del tipo de regla"; 
$LANG['rulesengine'][25]="Nombre del ordenador"; 
$LANG['rulesengine'][26]="La expresión regular se verifica"; 
$LANG['rulesengine'][27]="La expresión regular no se verifica"; 
$LANG['rulesengine'][28]="Reglas de negocio para el seguimiento"; 
$LANG['rulesengine'][29]="Lista de reglas"; 
$LANG['rulesengine'][30]="Acción"; 
$LANG['rulesengine'][33]="Diccionario de los títulos"; 
$LANG['rulesengine'][35]="Diccionario de software"; 
$LANG['rulesengine'][36]="Diccionario de fabricantes"; 
$LANG['rulesengine'][37]="Reglas de asignación de categoría a los programas"; 
$LANG['rulesengine'][38]="Recalcular"; 
$LANG['rulesengine'][40]="la categoría"; 
$LANG['rulesengine'][41]="Validación"; 
$LANG['rulesengine'][42]="Y"; 
$LANG['rulesengine'][43]="O"; 
$LANG['rulesengine'][45]="Asigna el valor de la expresión regular"; 
$LANG['rulesengine'][46]="Asignar : IP del equipo"; 
$LANG['rulesengine'][47]="Asignar : nombre del equipo + dominio"; 
$LANG['rulesengine'][48]="Asignar material"; 
$LANG['rulesengine'][49]="Asignar : material por la dirección MAC"; 
$LANG['rulesengine'][50]="Diccionario modelo de ordenador"; 
$LANG['rulesengine'][51]="Diccionario tipos de monitores"; 
$LANG['rulesengine'][52]="Diccionario modelos de teléfonos"; 
$LANG['rulesengine'][53]="Diccionario modelos de periféricos"; 
$LANG['rulesengine'][54]="Diccionario de modelos de impresoras"; 
$LANG['rulesengine'][55]="Diccionario de modelos de electrónica de red"; 
$LANG['rulesengine'][56]="Modelos"; 
$LANG['rulesengine'][60]="Diccionario tipos de ordenadores"; 
$LANG['rulesengine'][61]="Diccionario tipo de monitor"; 
$LANG['rulesengine'][62]="Diccionario tipos de teléfonos"; 
$LANG['rulesengine'][63]="Diccionario tipos de periféricos"; 
$LANG['rulesengine'][64]="Diccionario de tipos de impresoras"; 
$LANG['rulesengine'][65]="Diccionario de tipos de electrónica de red"; 
$LANG['rulesengine'][66]="Tipos"; 
$LANG['rulesengine'][67]="Diccionario de S.O."; 
$LANG['rulesengine'][68]="Diccionario de Service Packs"; 
$LANG['rulesengine'][69]="Diccionario de versiones"; 
$LANG['rulesengine'][70]="Reglas de asignación de una incidenca creada por correo"; 
$LANG['rulesengine'][76]="Retocar diccionario"; 
$LANG['rulesengine'][77]="Diccionarios"; 
$LANG['rulesengine'][78]="Versión"; 
$LANG['rulesengine'][79]="Añadir el resultado de la expresión regular"; 
$LANG['rulesengine'][80]="Diccionario general"; 
$LANG['rulesengine'][81]="Resultado de la regla"; 
$LANG['rulesengine'][82]="Detalle del resultado"; 
$LANG['rulesengine'][83]="Puede asignar el resultado de una expresión regular utilizando la cadena #0"; 
$LANG['rulesengine'][84]="Probar el motor de reglas"; 
$LANG['rulesengine'][85]="Resultado de la expresión regular"; 
$LANG['rulesengine'][86]="Reasignación de categoría del programa al borrar la actual"; 
$LANG['rulesengine'][87]="Material tirado a la papelera por el diccionario GLPI"; 
$LANG['rulesengine'][90]="Proceso realizandose..."; 
$LANG['rulesengine'][91]="Proceso terminado"; 
$LANG['rulesengine'][92]="Cuidado antes de ejecutar el diccionario"; 
$LANG['rulesengine'][93]="¡Aviso! Esta operación puede llevar software fusionado a la papelera.<br>Avise a los usuarios."; 
$LANG['rulesengine'][94]="FUSIÓN"; 
$LANG['rulesengine'][95]="Selecciona un fabricante"; 
$LANG['rulesengine'][96]="Repetir el diccionario para fabricante(s)<br> (----- = Todo)"; 
$LANG['rulesengine'][97]="Ningún elemento para comprobar"; 
$LANG['rulesengine'][100]="Información sobre la caché"; 
$LANG['rulesengine'][102]="Nombre de la regla"; 
$LANG['rulesengine'][103]="Objetos en caché"; 
$LANG['rulesengine'][104]="Valor original"; 
$LANG['rulesengine'][105]="Valor modificado"; 
$LANG['rulesengine'][106]="Sin cambios"; 
$LANG['rulesengine'][107]="Inactiva"; 
$LANG['rulesengine'][108]="original"; 
$LANG['rulesengine'][110]="Asignación de derechos"; 
$LANG['rulesengine'][111]="Asignación de entidades"; 
$LANG['rulesengine'][112]="Derechos y asignación de entidades"; 
$LANG['rulesengine'][120]="El motor se para cuando se verifique una de las reglas."; 
$LANG['rulesengine'][121]="El motor ejecuta todas las reglas."; 
$LANG['rulesengine'][122]="El motor pasa el resultado de una regla a las siguientes."; 
$LANG['rulesengine'][130]="Entidad desde LDAP"; 
$LANG['rulesengine'][131]="Entidad desde TAG"; 
$LANG['rulesengine'][132]="Ignorar la importación"; 
$LANG['rulesengine'][133]="Entidad del dominio"; 
$LANG['rulesengine'][134]="Rechazar correo (sin respuesta)"; 
$LANG['rulesengine'][135]="Rechazar correo (con respuesta)"; 
$LANG['rulesengine'][138]="Criterios LDAP"; 
$LANG['rulesengine'][140]="Añadir criterio"; 
$LANG['rulesengine'][142]="Listado de correos no importados"; 
$LANG['rulesengine'][144]="Entidad desde perfíl de usuario"; 
$LANG['rulesengine'][145]="Usuario con un único perfil"; 
$LANG['rulesengine'][146]="Con el perfil del usuario"; 
$LANG['rulesengine'][147]="Usuario con un único perfil"; 
$LANG['rulesengine'][148]="Dominio correo electrónico conocido"; 
$LANG['rulesengine'][150]="Las reglas que afectan a la entidad están desactivadas"; 

$LANG['search'][0]="Buscar"; 
$LANG['search'][1]="para todos"; 
$LANG['search'][2]="contiene"; 
$LANG['search'][4]="Ordenado por"; 
$LANG['search'][8]="Fecha inicial"; 
$LANG['search'][9]="Fecha final"; 
$LANG['search'][10]="en"; 
$LANG['search'][11]="Elementos mostrados"; 
$LANG['search'][12]="Especificar una fecha de finalización"; 
$LANG['search'][15]="No se encontraron elementos"; 
$LANG['search'][16]="Al menos"; 
$LANG['search'][17]="Añadir un criterio de búsqueda"; 
$LANG['search'][18]="Borrar un criterio de búsqueda"; 
$LANG['search'][19]="Añadir un criterio global de búsqueda"; 
$LANG['search'][20]="Borrar un criterio global de búsqueda"; 

$LANG['setup'][0]="Títulos"; 
$LANG['setup'][2]="Añadir usuario..."; 
$LANG['setup'][3]="Enlace LDAP"; 
$LANG['setup'][4]="Tipos de ordenadores"; 
$LANG['setup'][5]="Sistemas operativos"; 
$LANG['setup'][6]="Personalización"; 
$LANG['setup'][9]="Interfaz de red"; 
$LANG['setup'][10]="Visualiza el orden de apellido y nombre"; 
$LANG['setup'][14]="Correo electrónico"; 
$LANG['setup'][18]="Usuario"; 
$LANG['setup'][19]="Contraseña"; 
$LANG['setup'][20]="Confirmar contraseña"; 
$LANG['setup'][21]="Error : las dos contraseñas no son idénticas"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Seguimiento privado por defecto"; 
$LANG['setup'][40]="Tareas predeterminadas por defecto"; 
$LANG['setup'][41]="Idioma"; 
$LANG['setup'][42]="Tipos de electrónica de red"; 
$LANG['setup'][43]="Tipos de impresoras"; 
$LANG['setup'][44]="Tipos de monitores"; 
$LANG['setup'][45]="Tipos de caja"; 
$LANG['setup'][46]="Valor predeterminado"; 
$LANG['setup'][47]="Tipo de gráfica por defecto"; 
$LANG['setup'][48]="Valores por defecto"; 
$LANG['setup'][62]="Seleccione la categoría"; 
$LANG['setup'][63]="Cuidado, está a punto de borrar un título usado para uno o más elementos."; 
$LANG['setup'][64]="Si confirma la eliminación, a los elementos bajo este título se les asignará un valor NULL"; 
$LANG['setup'][65]="También puede reemplazar todas las ocurrencias de este título por otro:"; 
$LANG['setup'][67]="Autenticaciones externas"; 
$LANG['setup'][69]="Tipos de periféricos"; 
$LANG['setup'][70]="Configuración general"; 
$LANG['setup'][71]="Firmware"; 
$LANG['setup'][73]="Roseta"; 
$LANG['setup'][74]="No puede borrar este elemento porque posee sub-elementos"; 
$LANG['setup'][75]="Debajo de"; 
$LANG['setup'][79]="Categorías de incidencias"; 
$LANG['setup'][80]="Tipos de tercero"; 
$LANG['setup'][81]="Asuntos de los documentos"; 
$LANG['setup'][82]="Tipos de contactos"; 
$LANG['setup'][83]="Estado de materiales"; 
$LANG['setup'][84]="Tipos de cartuchos"; 
$LANG['setup'][85]="Tipos de contratos"; 
$LANG['setup'][86]="Tipos de memoria RAM"; 
$LANG['setup'][87]="Categorías Base de Conocimiento"; 
$LANG['setup'][88]="Red"; 
$LANG['setup'][89]="Dominio"; 
$LANG['setup'][90]="VLANs"; 
$LANG['setup'][91]="Modelos de ordenadores"; 
$LANG['setup'][92]="Tipos de consumibles"; 
$LANG['setup'][93]="Interfaces (disco duro, ...)"; 
$LANG['setup'][94]="Modelos de monitores"; 
$LANG['setup'][95]="Modelos de electrónica de red"; 
$LANG['setup'][96]="Modelos de impresoras"; 
$LANG['setup'][97]="Modelos de periféricos"; 
$LANG['setup'][98]="Categoría de la tarea"; 
$LANG['setup'][99]="Código de oficina"; 
$LANG['setup'][100]="Nº de código"; 
$LANG['setup'][101]="Número máximo de tareas (ejecución externa)"; 
$LANG['setup'][102]="Nivel del registro"; 
$LANG['setup'][103]="1- Crítico (Autenticaciones erróneas)"; 
$LANG['setup'][104]="2- Severo (No utilizado)"; 
$LANG['setup'][105]="3- Importante (Autenticaciones correctas)"; 
$LANG['setup'][106]="4- Avisos (Creación, borrado, seguimiento)"; 
$LANG['setup'][107]="5- Completo (Todo)"; 
$LANG['setup'][109]="Tiempo de conservación de los registros de los sistemas, en días (0=infinit"; 
$LANG['setup'][110]="Mostrar las incidencias nuevas al entrar en el sistema"; 
$LANG['setup'][111]="Cantidad de elementos a mostrar por página"; 
$LANG['setup'][112]="Cantidad máxima de caracteres para cada elemento de la lista"; 
$LANG['setup'][113]="Idioma predeterminado"; 
$LANG['setup'][114]="Colores de las prioridades"; 
$LANG['setup'][115]="Umbral de alarma predeterminado para los cartuchos y consumibles"; 
$LANG['setup'][116]="Asignar automáticamente las incidencias al responsable técnico"; 
$LANG['setup'][117]="Autorizar la consulta anónima de las Preguntas Frecuentes"; 
$LANG['setup'][118]="Texto en la página de inicio"; 
$LANG['setup'][119]="Configuración de la presentación"; 
$LANG['setup'][120]="Utilizar Ajax"; 
$LANG['setup'][121]="Comodín Ajax"; 
$LANG['setup'][122]="Ajax - Cantidad máxima de elementos mostrados cuando no se use comodín"; 
$LANG['setup'][123]="No utilizar Ajax si el número de elementos es inferior a (0=nunca)"; 
$LANG['setup'][124]="Inserción automática de usuarios a partir de fuentes externas de autenticación"; 
$LANG['setup'][125]="... Desde un origen externo"; 
$LANG['setup'][126]="Añadir directamente un usuario de una fuente externa"; 
$LANG['setup'][127]="Autocompletar campos de texto con Ajax"; 
$LANG['setup'][128]="Formato de fechas"; 
$LANG['setup'][129]="Mostrar los ID GLPI"; 
$LANG['setup'][130]="Tiempo en días que se conservarán los registros de esta tarea (0 para infinito)"; 
$LANG['setup'][132]="Mostrar nombre completo en la lista desplegable"; 
$LANG['setup'][133]="Activar el modo OCSNG"; 
$LANG['setup'][134]="Modo OCSNG"; 
$LANG['setup'][135]="Normal"; 
$LANG['setup'][136]="Traducción"; 
$LANG['setup'][137]="Depurar"; 
$LANG['setup'][138]="Utilizar GLPI en modo"; 
$LANG['setup'][139]="General"; 
$LANG['setup'][140]="Tipos"; 
$LANG['setup'][145]="S.O."; 
$LANG['setup'][147]="AJAX"; 
$LANG['setup'][148]="Intervalo para los horarios"; 
$LANG['setup'][149]="Número de decimales para los importes"; 
$LANG['setup'][150]="Formato de Número"; 
$LANG['setup'][154]="Base dn"; 
$LANG['setup'][155]="root dn (para las conexiones no anónimas)"; 
$LANG['setup'][156]="Pass (para las conexiones no anónimas)"; 
$LANG['setup'][157]="La extensión LDAP de su intérprete PHP no está instalada"; 
$LANG['setup'][158]="Imposible utilizar LDAP como origen de conexión externa"; 
$LANG['setup'][159]="Filtro de conexión"; 
$LANG['setup'][162]="Configuración IMAP/POP"; 
$LANG['setup'][164]="Nombre de dominio IMAP/POP <br>(formato correo del tipo usuario@dominio)"; 
$LANG['setup'][165]="La extensión IMAP de su intérprete PHP no está instalada"; 
$LANG['setup'][166]="Imposible utilizar IMAP/POP como origen de conexión externa"; 
$LANG['setup'][167]="Enlace GLPI/LDAP"; 
$LANG['setup'][168]="Opciones de conexión"; 
$LANG['setup'][169]="Carpeta de correo (opcional, normalmente INBOX)"; 
$LANG['setup'][170]="Cadena de conexión"; 
$LANG['setup'][171]="Puerto (opcional)"; 
$LANG['setup'][172]="Puerto LDAP (predeterminado=389)"; 
$LANG['setup'][174]="Servidor CAS"; 
$LANG['setup'][175]="Puerto"; 
$LANG['setup'][176]="Directorio de base (opcional)"; 
$LANG['setup'][177]="Configuración CAS"; 
$LANG['setup'][178]="La extensión CURL o DOMXML de su intérprete PHP no está instalada"; 
$LANG['setup'][179]="Imposible utilizar CAS como origen de conexión externa"; 
$LANG['setup'][180]="Utilizar TLS"; 
$LANG['setup'][181]="Función ldap_start_tls inexistente"; 
$LANG['setup'][182]="URL de retorno al salir de la aplicación (logout)"; 
$LANG['setup'][185]="Registros en ficheros (SQL, email, cron...)"; 
$LANG['setup'][186]="Huso horario"; 
$LANG['setup'][190]="Certificado x509"; 
$LANG['setup'][191]="Atributos de correo para x509"; 
$LANG['setup'][192]="Activado"; 
$LANG['setup'][193]="Campo de almacenamiento del usuario en el conjunto _SERVER"; 
$LANG['setup'][194]="Recuperación de datos complementarios usando LDAP"; 
$LANG['setup'][195]="Mantener estado"; 
$LANG['setup'][196]="Borrar estado"; 
$LANG['setup'][197]="Copiar estado del ordenador"; 
$LANG['setup'][198]="Configurar estado"; 
$LANG['setup'][199]="Suprima @domain del inicio de sesión en la forma login@domain"; 
$LANG['setup'][200]="Infinito"; 
$LANG['setup'][201]="Configuración de la función"; 
$LANG['setup'][202]="Utilizar el seguimiento por correo"; 
$LANG['setup'][203]="Correo del administrador"; 
$LANG['setup'][204]="Firma de los mensajes"; 
$LANG['setup'][205]="Mensaje de prueba enviado al administrador"; 
$LANG['setup'][206]="Fracaso del envío de mensaje de prueba al administrador"; 
$LANG['setup'][207]="Dirección del correo de respuesta (si es necesario)"; 
$LANG['setup'][217]="La función de mail PHP no existe o está desactivada en su sistema"; 
$LANG['setup'][218]="Es imprescindible utilizar un servidor SMTP"; 
$LANG['setup'][219]="Permitir las aperturas de incidencias anónimas (helpdesk.html)"; 
$LANG['setup'][221]="Fecha de inicio del ejercicio fiscal (día y mes)"; 
$LANG['setup'][223]="Límite de horarios para la planificación"; 
$LANG['setup'][227]="URL de base utilizado"; 
$LANG['setup'][228]="Campo de usuario"; 
$LANG['setup'][229]="Prueba de envío de correo electrónico al administrador"; 
$LANG['setup'][231]="Utilizar un servidor SMTP para el envío de correo"; 
$LANG['setup'][232]="Servidor SMTP"; 
$LANG['setup'][234]="Inicio sesión (login) SMTP (opcional)"; 
$LANG['setup'][235]="Contraseña SMTP"; 
$LANG['setup'][236]="Técnico anteriormente encargado de la incidencia"; 
$LANG['setup'][237]="Administrador"; 
$LANG['setup'][239]="Técnico encargado de la incidencia"; 
$LANG['setup'][240]="Opciones de notificación"; 
$LANG['setup'][241]="No hay criterios personales. ¿Desea crear sus parámetros personales?"; 
$LANG['setup'][242]="Opciones de alertas"; 
$LANG['setup'][243]="Alertas sobre consumibles"; 
$LANG['setup'][244]="Alertas sobre cartuchos"; 
$LANG['setup'][245]="Recordatorios"; 
$LANG['setup'][246]="Alertas sobre contratos"; 
$LANG['setup'][247]="Alertas sobre datos financieros"; 
$LANG['setup'][248]="Grupo encargado de la incidencia"; 
$LANG['setup'][249]="Grupo solicitante"; 
$LANG['setup'][250]="Vistas predeterminadas"; 
$LANG['setup'][252]="Seleccione los elementos que se mostrarán de forma predeterminada"; 
$LANG['setup'][253]="Filtro para búsqueda en los grupos"; 
$LANG['setup'][254]="Tipo de búsqueda"; 
$LANG['setup'][255]="Atributo de los grupos que contienen los usuarios"; 
$LANG['setup'][256]="En los usuarios"; 
$LANG['setup'][257]="En los grupos"; 
$LANG['setup'][258]="Usuarios y grupos"; 
$LANG['setup'][259]="Pertenencia a grupos"; 
$LANG['setup'][260]="Atributo del usuario que indica sus grupos"; 
$LANG['setup'][261]="DN del grupo"; 
$LANG['setup'][262]="Usar DN en la búsqueda"; 
$LANG['setup'][263]="Filtro de búsqueda para usuarios"; 
$LANG['setup'][264]="Aviso de expiración de licencias"; 
$LANG['setup'][271]="Restringir la gestión de monitores"; 
$LANG['setup'][272]="Restringir la gestión de periféricos"; 
$LANG['setup'][273]="Restringir la gestión de teléfonos"; 
$LANG['setup'][274]="para añadir manualmente"; 
$LANG['setup'][275]="Restringir la gestión de impresoras"; 
$LANG['setup'][280]="Actualización automática de los elementos relacionados con los ordenadores"; 
$LANG['setup'][281]="Conectar / actualizar comportamiento"; 
$LANG['setup'][282]="Desconectar comportamiento"; 
$LANG['setup'][283]="Copiar"; 
$LANG['setup'][284]="Limpiar"; 
$LANG['setup'][285]="No copiar"; 
$LANG['setup'][286]="No borrar"; 
$LANG['setup'][300]="Comprobar si hay una nueva versión disponible"; 
$LANG['setup'][301]="Hay disponible una nueva versión:"; 
$LANG['setup'][302]="La encontrará en la página : <a href='http://glpi-project.org' target='_blank'>http://glpi-project.org</a>"; 
$LANG['setup'][303]="Tiene instalada la última versión disponible"; 
$LANG['setup'][304]="Verificación imposible. Si está detrás de un proxy, configúrelo."; 
$LANG['setup'][305]="Todos los días"; 
$LANG['setup'][306]="Comprobar la presencia de actualizaciones"; 
$LANG['setup'][307]="Nunca"; 
$LANG['setup'][308]="Todas las semanas"; 
$LANG['setup'][309]="Todos los meses"; 
$LANG['setup'][310]="Imposible conectar con el sitio."; 
$LANG['setup'][311]="Imposible conectarse al servidor proxy"; 
$LANG['setup'][312]="No hay datos disponibles en este sitio web"; 
$LANG['setup'][313]="Atención : no existe valor por defecto"; 
$LANG['setup'][350]="Relación con los materiales para la apertura de incidencias"; 
$LANG['setup'][351]="Todos los materiales"; 
$LANG['setup'][352]="Materiales asociables con una incidencia"; 
$LANG['setup'][360]="Campos automáticos (marcados con *)"; 
$LANG['setup'][400]="Configuración del proxy"; 
$LANG['setup'][407]="Enlace a la Ayuda del CAU"; 
$LANG['setup'][408]="Enlace a la Ayuda Central"; 
$LANG['setup'][409]="Asunto predeterminado de los documentos relacionados con las incidencias"; 
$LANG['setup'][503]="Modelos de teléfonos"; 
$LANG['setup'][504]="Tipos de teléfonos"; 
$LANG['setup'][505]="Tipo de alimentación del teléfono"; 
$LANG['setup'][601]="Valor LDAP"; 
$LANG['setup'][602]="Conexión a la base de datos OCSNG"; 
$LANG['setup'][603]="Añadir un usuario"; 
$LANG['setup'][604]="Asociar a un grupo"; 
$LANG['setup'][606]="No se puede añadir. Este usuario ya existe."; 
$LANG['setup'][607]="Asociar a un perfil"; 
$LANG['setup'][608]="Programa asociable a una incidencia por defecto"; 
$LANG['setup'][609]="Imposible añadir. El servidor OCSNG ya existe."; 
$LANG['setup'][610]="Título de incidencia obligatorio"; 
$LANG['setup'][611]="El contenido de la incidencia es obligatorio"; 
$LANG['setup'][612]="La categoría de la incidencia es obligatoria"; 
$LANG['setup'][613]="Añadir un usuario LDAP sin derechos"; 
$LANG['setup'][614]="Imposible actualizar acceso. El usuario ya existe,"; 
$LANG['setup'][615]="Ciclo de vida de las incidencias"; 
$LANG['setup'][616]="De \ A"; 
$LANG['setup'][620]="Enlace"; 
$LANG['setup'][621]="Filtro de búsqueda de las entidades"; 
$LANG['setup'][622]="Atributo en representación de la entidad"; 
$LANG['setup'][623]="Importar entidades desde LDAP"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Servidor de correo"; 
$LANG['setup'][661]="Configuración de las notificaciones imposible : activar el seguimiento por correo electrónico"; 
$LANG['setup'][703]="General"; 
$LANG['setup'][704]="Notificaciones"; 
$LANG['setup'][707]="Alertas sobre reservas"; 
$LANG['setup'][708]="Alertas de incidencias sin resolver desde hace"; 
$LANG['setup'][720]="Info. Sistema"; 
$LANG['setup'][721]="Información sobre la instalación y configuración del sistema"; 
$LANG['setup'][722]="Para pegar/copiar en su petición de soporte"; 
$LANG['setup'][731]="Valor de la configuración general"; 
$LANG['setup'][732]="Dominio del servicio de correo electrónico"; 
$LANG['setup'][800]="Replicar Mysql"; 
$LANG['setup'][801]="Habilitar la réplica MySQL"; 
$LANG['setup'][802]="Base"; 
$LANG['setup'][803]="Diferencia entre maestro y esclavo"; 
$LANG['setup'][806]="Máxima diferencia entre maestro y esclavo"; 
$LANG['setup'][807]="La base de datos esclava está desincronizada. La diferencia es de:"; 
$LANG['setup'][808]="¡Base de datos esclava desincronizada!"; 
$LANG['setup'][809]="Replicar MySQL : solo lectura"; 
$LANG['setup'][810]="Desincronización de la réplica de MYSQL"; 

$LANG['software'][1]="Versión comprada"; 
$LANG['software'][2]="Versión en uso"; 
$LANG['software'][3]="Licencias afectadas y no instaladas"; 
$LANG['software'][4]="Ilimitado"; 
$LANG['software'][5]="Versiones"; 
$LANG['software'][6]="Editor"; 
$LANG['software'][7]="Añadir versión"; 
$LANG['software'][8]="Añadir una licencia"; 
$LANG['software'][11]="Licencias"; 
$LANG['software'][17]="programa(s) instalado(s)"; 
$LANG['software'][19]="Instalaciones"; 
$LANG['software'][20]="Restante"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Actualización"; 
$LANG['software'][30]="Tipo de licencias"; 
$LANG['software'][32]="Expiración"; 
$LANG['software'][44]="Instalación de un software"; 
$LANG['software'][45]="Desinstalación de un software"; 
$LANG['software'][46]="Asociable a una incidencia"; 
$LANG['software'][47]="Agrupación"; 
$LANG['software'][48]="Reagrupar"; 
$LANG['software'][49]="Programas enviados a la papelera después de reagrupar"; 
$LANG['software'][50]="Asignado a la computadora"; 
$LANG['software'][51]="El número debe ser 1 para que tenga efecto"; 

$LANG['softwarecategories'][2]="Programas sin categoría"; 
$LANG['softwarecategories'][3]="Programa sin categorizar instalado"; 
$LANG['softwarecategories'][4]="Desplegar programas pertenecientes a una categoría"; 
$LANG['softwarecategories'][5]="Categoría de programas"; 

$LANG['state'][0]="Estado"; 
$LANG['state'][6]="Tipo de material"; 
$LANG['state'][7]="No se encontraron materiales"; 
$LANG['state'][11]="Resumen"; 

$LANG['stats'][0]="Seleccione las estadísticas que desea ver"; 
$LANG['stats'][1]="Globales"; 
$LANG['stats'][2]="No hay artículos para mostrar"; 
$LANG['stats'][3]="Por títulos"; 
$LANG['stats'][5]="Total de incidencias abiertas"; 
$LANG['stats'][6]="Demora media del tratamiento de incidencias"; 
$LANG['stats'][7]="Ver gráficos"; 
$LANG['stats'][11]="Incidencias cerradas"; 
$LANG['stats'][13]="Incidencias asignadas"; 
$LANG['stats'][15]="Duración media del tratamiento de incidencias"; 
$LANG['stats'][16]="Nombre del técnico"; 
$LANG['stats'][20]="Nombre de usuario"; 
$LANG['stats'][23]="No hay estadísticas disponibles"; 
$LANG['stats'][25]="Duración real media de tratamiento del servicio"; 
$LANG['stats'][27]="Duración real total de servicios"; 
$LANG['stats'][30]="Demora media de atención de servicio"; 
$LANG['stats'][31]="Días"; 
$LANG['stats'][33]="Mins"; 
$LANG['stats'][34]="Segs"; 
$LANG['stats'][35]="Servicios"; 
$LANG['stats'][44]="Nombre del proveedor"; 
$LANG['stats'][45]="Por material"; 
$LANG['stats'][47]="Por incidencias"; 
$LANG['stats'][48]="(asignado)"; 
$LANG['stats'][49]="(seguimiento)"; 

$LANG['title'][5]="Base de conocimiento"; 
$LANG['title'][6]="Electrónica de red"; 
$LANG['title'][9]="Estados de materiales"; 
$LANG['title'][10]="Seguimiento de incidencias"; 
$LANG['title'][13]="Información del usuario"; 
$LANG['title'][14]="Fuentes de autenticación externas"; 
$LANG['title'][24]="Soporte"; 
$LANG['title'][26]="Principal"; 
$LANG['title'][27]="Conexiones"; 
$LANG['title'][28]="Incidencias"; 
$LANG['title'][30]="Componentes"; 
$LANG['title'][33]="Enlaces externos"; 
$LANG['title'][34]="Enlace"; 
$LANG['title'][37]="Notas"; 
$LANG['title'][38]="Histórico"; 
$LANG['title'][40]="Notas personales y públicas"; 
$LANG['title'][42]="Modificación masiva"; 
$LANG['title'][43]="Registro del sistema"; 

$LANG['tracking'][1]="Mis materiales"; 
$LANG['tracking'][2]="O búsqueda completa"; 
$LANG['tracking'][3]="Datos inválidos. Actualización cancelada"; 
$LANG['tracking'][4]="Su petición no tiene urgencia, mirar de corregir"; 
$LANG['tracking'][8]="Su incidencia no tiene descripción. Por favor, complétela."; 
$LANG['tracking'][9]="Origen por defecto para helpdesk"; 
$LANG['tracking'][10]="Origen por defecto para los recolectores"; 
$LANG['tracking'][24]="Documento de Incidencia"; 
$LANG['tracking'][29]="Cantidad"; 
$LANG['tracking'][30]="Nuevas"; 
$LANG['tracking'][31]="En curso (asignadas)"; 
$LANG['tracking'][32]="En curso (planificadas)"; 
$LANG['tracking'][34]="Directa"; 
$LANG['tracking'][35]="Escrita"; 
$LANG['tracking'][37]="Conservar las incidencias al purgar un elemento del inventario"; 
$LANG['tracking'][38]="Correo de seguimiento enviado a"; 
$LANG['tracking'][39]="Visible en la interfaz del Helpdesk"; 

$LANG['transfer'][1]="Transferencia"; 
$LANG['transfer'][3]="Si ya no se usa"; 
$LANG['transfer'][4]="Vaciar la lista de elementos a transferir"; 
$LANG['transfer'][5]="Puede añadir más elementos o transferir los que hay ahora"; 
$LANG['transfer'][6]="Se recomienda hacer una copia de seguridad antes de transferir elementos."; 
$LANG['transfer'][7]="Elementos a transferir"; 
$LANG['transfer'][8]="Modo de transferencia"; 

$LANG['update'][88]="Su versión de la base de datos no es compatible con la versión del código instalado. Es necesaria una actualización."; 
$LANG['update'][89]="Está intentando utilizar GLPI con una versión de la base de datos prevista para una versión superior. Por favor, instale la versión correspondiente a su base de datos."; 
$LANG['update'][90]="Error durante la actualización de la base de datos"; 
$LANG['update'][91]="¡Cuidado!"; 
$LANG['update'][92]="Va a actualizar la base de datos GLPI que se llama:"; 
$LANG['update'][93]="La conexión con la base de datos ha sido correcta"; 
$LANG['update'][94]="La actualización ha sido correcta, su base de datos está actualizada"; 
$LANG['update'][95]="La conexión a la base de datos ha fallado, compruebe los parámetros de conexión que figuran en el fichero config_db.php"; 
$LANG['update'][96]="Todos los administradores tienen permisos de 'super-admin'. También se ha añadido este nuevo tipo de usuario."; 
$LANG['update'][105]="¡Imposible acceder a la actualización de esta forma!"; 
$LANG['update'][106]="Volver a GLPI"; 
$LANG['update'][107]="Ahora debe proceder a la actualización del contenido anterior de su base de datos"; 
$LANG['update'][130]="Actualización de lugares"; 
$LANG['update'][131]="La nueva estructura es jerárquica"; 
$LANG['update'][132]="Si utiliza un carácter de separación puede indicarlo para automatizar la generación de la jerarquía"; 
$LANG['update'][133]="Puede también especificar un lugar de base que incluirá todos los lugares generados."; 
$LANG['update'][134]="Carácter de separación"; 
$LANG['update'][135]="Lugar raíz"; 
$LANG['update'][136]="He aquí la nueva jerarquía generada. Si es correcta puede aceptarla."; 
$LANG['update'][137]="Nueva jerarquía"; 
$LANG['update'][138]="Lugares actuales"; 
$LANG['update'][139]="Optimización de las tablas"; 
$LANG['update'][140]="Crear índices"; 
$LANG['update'][141]="Modificación del esquema"; 
$LANG['update'][142]="Recuperación de Datos"; 

$LANG['users'][1]="Título"; 
$LANG['users'][2]="Categoría"; 

$LANG['validation'][0]="Validación"; 
$LANG['validation'][1]="Enviar una solicitud de validación"; 
$LANG['validation'][2]="Estado"; 
$LANG['validation'][3]="Fecha de la solicitud"; 
$LANG['validation'][4]="Fecha de la validación"; 
$LANG['validation'][5]="Comentario de la solicitud"; 
$LANG['validation'][6]="Comentario de la validación"; 
$LANG['validation'][7]="Validación(es) para la incidencia"; 
$LANG['validation'][9]="En espera de validación"; 
$LANG['validation'][10]="Rechazado"; 
$LANG['validation'][11]="Aceptada"; 
$LANG['validation'][12]="No está sujeto a la validación"; 
$LANG['validation'][13]="Solicitud de validación enviada a"; 
$LANG['validation'][15]="Incidencia en espera de su validación"; 
$LANG['validation'][16]="Opcional si aceptada"; 
$LANG['validation'][18]="Solicitante de la validación"; 
$LANG['validation'][19]="Validación aceptada"; 
$LANG['validation'][20]="Validación rehusada"; 
$LANG['validation'][21]="Usuario de validación"; 
$LANG['validation'][23]="El usuario elegido no tiene correo electrónico. La petición se ha creado pero el envío de correo ha fallado."; 
$LANG['validation'][26]="Solicitud de validación"; 
$LANG['validation'][27]="Se ha solicitado una petición de validación"; 
$LANG['validation'][28]="Estado de la petición de validación"; 
$LANG['validation'][29]="En caso de rechazar la validación, debe indicar un motivo"; 
$LANG['validation'][30]="Suprimir la solicitud de validación"; 
$LANG['validation'][31]="Actualizar la solicitud de validación"; 
$LANG['validation'][32]="Una respuesta a una solicitud de validación se llevó a cabo"; 
$LANG['validation'][33]="Incidencias esperan su aprobación"; 
?>